@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -41,7 +41,7 @@
 
 #include <api/na-core-utils.h>
 
-#include "na-iabout.h"
+#include "na-about.h"
 
 static GSList  *text_to_string_list( const gchar *text, const gchar *separator, const gchar *default_value );
 static gboolean info_dir_is_writable( GFile *file, const gchar *path );
@@ -52,11 +52,15 @@ static gboolean info_dir_is_writable( GFile *file, const gchar *path );
  *
  * Returns: %TRUE if the string evaluates to "true" (case insensitive),
  * %FALSE else.
+ *
+ * Since: 2.30
  */
 gboolean
 na_core_utils_boolean_from_string( const gchar *string )
 {
-	return( g_ascii_strcasecmp( string, "true" ) == 0 );
+	if( !string ) return( FALSE );
+
+	return( g_ascii_strcasecmp( string, "true" ) == 0 || atoi( string ) != 0 );
 }
 
 /**
@@ -67,6 +71,8 @@ na_core_utils_boolean_from_string( const gchar *string )
  * Appends a prefix to each line of the string.
  *
  * Returns: a new string which should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_core_utils_str_add_prefix( const gchar *prefix, const gchar *str )
@@ -91,7 +97,20 @@ na_core_utils_str_add_prefix( const gchar *prefix, const gchar *str )
  * @str1: an UTF-8 encoded string.
  * @str2: an UTF-8 encoded string.
  *
- * Returns: -1 if str1 < str2, 0 if str1 = str2, +1 if str1 > str2.
+ * Returns:
+ * <itemizedlist>
+ *   <listitem>
+ *     <para>-1 if str1 < str2,</para>
+ *   </listitem>
+ *   <listitem>
+ *     <para>0 if str1 = str2,</para>
+ *   </listitem>
+ *   <listitem>
+ *     <para>+1 if str1 > str2.</para>
+ *   </listitem>
+ * </itemizedlist>
+ *
+ * Since: 2.30
  */
 int
 na_core_utils_str_collate( const gchar *str1, const gchar *str2 )
@@ -100,10 +119,13 @@ na_core_utils_str_collate( const gchar *str1, const gchar *str2 )
 
 	if( str1 && str2 ){
 		res = g_utf8_collate( str1, str2 );
+
 	} else if( !str1 && !str2 ){
 		res = 0;
+
 	} else if( !str1 ){
 		res = -1;
+
 	} else {
 		g_return_val_if_fail( str2 == NULL, 0 );
 		res = 1;
@@ -120,6 +142,8 @@ na_core_utils_str_collate( const gchar *str1, const gchar *str2 )
  * minus all the found occurrences of the given @to_remove char.
  *
  * The returned string should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_core_utils_str_remove_char( const gchar *string, const gchar *to_remove )
@@ -162,6 +186,8 @@ na_core_utils_str_remove_char( const gchar *string, const gchar *to_remove )
  * @suffix, then the returned string is equal to source @string.
  *
  * The returned string should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_core_utils_str_remove_suffix( const gchar *string, const gchar *suffix )
@@ -186,10 +212,18 @@ na_core_utils_str_remove_suffix( const gchar *string, const gchar *suffix )
  * @other: a pointer to a gchar *.
  *
  * Split the @string string into two components:
- * - the first word which is allocated in @first,
- * - the rest of the string which is allocated in @other.
+ * <itemizedlist>
+ *   <listitem>
+ *     <para>the first word which is allocated in @first,</para>
+ *   </listitem>
+ *   <listitem>
+ *     <para>the rest of the string which is allocated in @other.</para>
+ *   </listitem>
+ * </itemizedlist>
  *
  * The two allocated strings should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 void
 na_core_utils_str_split_first_word( const gchar *string, gchar **first, gchar **other )
@@ -218,6 +252,38 @@ na_core_utils_str_split_first_word( const gchar *string, gchar **first, gchar **
 	}
 }
 
+/**
+ * na_core_utils_str_subst:
+ * @pattern: the pattern.
+ * @key: the key string to be substituted.
+ * @subst: the string which will replace @key.
+ *
+ * Returns: a copy of @pattern where the first occurrence of @key has been
+ * substituted with @subst, as a newly allocated string which should be
+ * g_free() by the caller.
+ *
+ * Returns: a copy of @pattern if @key is not found in @pattern.
+ */
+gchar *
+na_core_utils_str_subst( const gchar *pattern, const gchar *key, const gchar *subst )
+{
+	GString *result;
+	gchar *found;
+
+	result = g_string_new( "" );
+	found = g_strstr_len( pattern, -1, key );
+	if( found ){
+		result = g_string_append_len( result, pattern, ( gssize )( found - pattern ));
+		result = g_string_append( result, subst );
+		result = g_string_append( result, found + g_utf8_strlen( key, -1 ));
+
+	} else {
+		result = g_string_append( result, pattern );
+	}
+
+	return( g_string_free( result, FALSE ));
+}
+
 void
 na_core_utils_slist_add_message( GSList **messages, const gchar *format, ... )
 {
@@ -238,6 +304,8 @@ na_core_utils_slist_add_message( GSList **messages, const gchar *format, ... )
  * Returns: a #GSList of strings.
  *
  * The returned list should be na_core_utils_slist_free() by the caller.
+ *
+ * Since: 2.30
  */
 GSList *
 na_core_utils_slist_duplicate( GSList *slist )
@@ -261,6 +329,8 @@ na_core_utils_slist_duplicate( GSList *slist )
  * @list: a list of strings.
  *
  * Dumps the content of a list of strings.
+ *
+ * Since: 2.30
  */
 void
 na_core_utils_slist_dump( const gchar *prefix, GSList *list )
@@ -275,7 +345,8 @@ na_core_utils_slist_dump( const gchar *prefix, GSList *list )
 	g_debug( "%s: list at %p has %d element(s)", thispfx, ( void * ) list, g_slist_length( list ));
 
 	for( i=list, c=0 ; i ; i=i->next ){
-		g_debug( "%s: [%2d] %s", thispfx, c++, ( gchar * ) i->data );
+		g_debug( "%s: [%2d] %s (%lu)",
+				thispfx, c++, ( gchar * ) i->data, g_utf8_strlen( ( gchar * ) i->data, -1 ));
 	}
 }
 
@@ -287,6 +358,8 @@ na_core_utils_slist_dump( const gchar *prefix, GSList *list )
  * Returns: a #GSList with the list of strings after having been splitted.
  *
  * The returned #GSList should be na_core_utils_slist_free() by the caller.
+ *
+ * Since: 2.30
  */
 GSList *
 na_core_utils_slist_from_split( const gchar *text, const gchar *separator )
@@ -321,6 +394,8 @@ na_core_utils_slist_from_split( const gchar *text, const gchar *separator )
  *
  * Returns: a #GSList list of strings, which should be #na_core_utils_slist_free()
  * by the caller.
+ *
+ * Since: 2.30
  */
 GSList *
 na_core_utils_slist_from_array( const gchar **str_array )
@@ -345,6 +420,8 @@ na_core_utils_slist_from_array( const gchar **str_array )
  * @link: the string used to join each element.
  *
  * Returns: a newly allocated string which should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_core_utils_slist_join_at_end( GSList *slist, const gchar *link )
@@ -372,6 +449,8 @@ na_core_utils_slist_join_at_end( GSList *slist, const gchar *link )
  * Removes a string from a GSList of strings.
  *
  * Returns: the same, updated, @slist.
+ *
+ * Since: 2.30
  */
 GSList *
 na_core_utils_slist_remove_ascii( GSList *slist, const gchar *text )
@@ -400,6 +479,8 @@ na_core_utils_slist_remove_ascii( GSList *slist, const gchar *text )
  * @text.
  *
  * Returns: the new @slist start position.
+ *
+ * Since: 2.30
  */
 GSList *
 na_core_utils_slist_remove_utf8( GSList *slist, const gchar *text )
@@ -424,6 +505,8 @@ na_core_utils_slist_remove_utf8( GSList *slist, const gchar *text )
  *
  * Returns: a newly allocated array of strings, which should be
  * g_strfreev() by the caller.
+ *
+ * Since: 2.30
  */
 gchar **
 na_core_utils_slist_to_array( GSList *slist )
@@ -451,6 +534,8 @@ na_core_utils_slist_to_array( GSList *slist )
  *
  * Returns: a newly allocated string, which should be g_free() by the
  * caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_core_utils_slist_to_text( GSList *slist )
@@ -483,6 +568,8 @@ na_core_utils_slist_to_text( GSList *slist )
  * or not if @set is %FALSE.
  *
  * Returns: the updated @list.
+ *
+ * Since: 2.30
  */
 GSList *
 na_core_utils_slist_setup_element( GSList *list, const gchar *element, gboolean set )
@@ -509,6 +596,8 @@ na_core_utils_slist_setup_element( GSList *list, const gchar *element, gboolean
  * Search for a string in a string list.
  *
  * Returns: the count of @ßtr in @list list.
+ *
+ * Since: 2.30
  */
 guint
 na_core_utils_slist_count( GSList *list, const gchar *str )
@@ -536,6 +625,8 @@ na_core_utils_slist_count( GSList *list, const gchar *str )
  * Search for a string in a string list which may contain nagated items.
  *
  * Returns: %TRUE if the string has been found in list.
+ *
+ * Since: 2.30
  */
 gboolean
 na_core_utils_slist_find_negated( GSList *list, const gchar *str )
@@ -569,6 +660,8 @@ na_core_utils_slist_find_negated( GSList *list, const gchar *str )
  * Compare two string lists, without regards to the order.
  *
  * Returns: %TRUE if the two lists have same content.
+ *
+ * Since: 2.30
  */
 gboolean
 na_core_utils_slist_are_equal( GSList *a, GSList *b )
@@ -597,6 +690,8 @@ na_core_utils_slist_are_equal( GSList *a, GSList *b )
  * @slist: a #GSList list of strings.
  *
  * Releases the strings and the list itself.
+ *
+ * Since: 2.30
  */
 void
 na_core_utils_slist_free( GSList *slist )
@@ -614,6 +709,8 @@ na_core_utils_slist_free( GSList *slist )
  * Concatenates a gchar **list of strings to a new string.
  *
  * Returns: a newly allocated string which should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_core_utils_gstring_joinv( const gchar *start, const gchar *separator, gchar **list )
@@ -678,6 +775,8 @@ text_to_string_list( const gchar *text, const gchar *separator, const gchar *def
  * relevant integer.
  *
  * The two returned strings must be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 void
 na_core_utils_selcount_get_ope_int( const gchar *selcount, gchar **ope, gchar **uint )
@@ -713,6 +812,8 @@ na_core_utils_selcount_get_ope_int( const gchar *selcount, gchar **ope, gchar **
  * but before the caller has been able to actually write into it.
  *
  * There is no "super-test". Just try...
+ *
+ * Since: 2.30
  */
 gboolean
 na_core_utils_dir_is_writable_path( const gchar *path )
@@ -744,6 +845,8 @@ na_core_utils_dir_is_writable_path( const gchar *path )
  * but before the caller has been able to actually write into it.
  *
  * There is no "super-test". Just try...
+ *
+ * Since: 2.30
  */
 gboolean
 na_core_utils_dir_is_writable_uri( const gchar *uri )
@@ -812,6 +915,8 @@ info_dir_is_writable( GFile *file, const gchar *path_or_uri )
  * allocated buffers which should be g_free() by the caller.
  *
  * The extension is set to an empty string if no extension is detected.
+ *
+ * Since: 2.30
  */
 void
 na_core_utils_dir_split_ext( const gchar *string, gchar **first, gchar **ext )
@@ -849,6 +954,8 @@ na_core_utils_dir_split_ext( const gchar *string, gchar **first, gchar **ext )
  * @path: the path of the file to be deleted.
  *
  * Returns: %TRUE if the file is successfully deleted, %FALSE else.
+ *
+ * Since: 2.30
  */
 gboolean
 na_core_utils_file_delete( const gchar *path )
@@ -876,7 +983,10 @@ na_core_utils_file_delete( const gchar *path )
  *
  * Returns: %TRUE if the specified file exists, %FALSE else.
  *
- * Race condition: cf. na_core_utils_dir_is_writable() comment.
+ * Race condition: cf. na_core_utils_dir_is_writable_path() and
+ * na_core_utils_dir_is_writable_uri() comments.
+ *
+ * Since: 2.30
  */
 gboolean
 na_core_utils_file_exists( const gchar *uri )
@@ -894,13 +1004,15 @@ na_core_utils_file_exists( const gchar *uri )
 /**
  * na_core_utils_file_load_from_uri:
  * @uri: the URI the file must be loaded from.
- * @length: a pointer to the length of the readen content.
+ * @length: a pointer to the length of the read content.
  *
  * Loads the file into a newly allocated buffer, and set up the length of the
- * readen content if not %NULL.
+ * read content if not %NULL.
  *
  * Returns: the newly allocated buffer which contains the file content, or %NULL.
  * This buffer should be g_free() by the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_core_utils_file_load_from_uri( const gchar *uri, gsize *length )
@@ -928,10 +1040,14 @@ na_core_utils_file_load_from_uri( const gchar *uri, gsize *length )
  *
  * Print a version message on the console
  *
- * nautilus-actions-new (Nautilus-Actions) v 2.29.1
- * Copyright (C) 2005-2007 Frederic Ruaudel
- * Copyright (C) 2009, 2010 Pierre Wieser
- * Nautilus-Actions is free software, licensed under GPLv2 or later.
+ * <programlisting>
+ *   nautilus-actions-new (Nautilus-Actions) v 2.29.1
+ *   Copyright (C) 2005-2007 Frederic Ruaudel
+ *   Copyright (C) 2009, 2010, 2011 Pierre Wieser
+ *   Nautilus-Actions is free software, licensed under GPLv2 or later.
+ * </programlisting>
+ *
+ * Since: 2.30
  */
 void
 na_core_utils_print_version( void )
@@ -940,7 +1056,7 @@ na_core_utils_print_version( void )
 
 	g_print( "\n" );
 	g_print( "%s (%s) v %s\n", g_get_prgname(), PACKAGE_NAME, PACKAGE_VERSION );
-	copyright = na_iabout_get_copyright( TRUE );
+	copyright = na_about_get_copyright( TRUE );
 	g_print( "%s\n", copyright );
 	g_free( copyright );
 
@@ -949,8 +1065,11 @@ na_core_utils_print_version( void )
 	g_print( "License (see COPYING).\n" );
 	g_print( "\n" );
 
-	g_debug( "Current system runs Glib %d.%d.%d, Gtk+ %d.%d.%d",
+	g_debug( "Program has been compiled against Glib %d.%d.%d, Gtk+ %d.%d.%d",
+			GLIB_MAJOR_VERSION, GLIB_MINOR_VERSION, GLIB_MICRO_VERSION,
+			GTK_MAJOR_VERSION, GTK_MINOR_VERSION, GTK_MICRO_VERSION );
+
+	g_debug( "Current system runs Glib %d.%d.%d, Gtk+ %d.%d.%d\n",
 			glib_major_version, glib_minor_version, glib_micro_version,
 			gtk_major_version, gtk_minor_version, gtk_micro_version );
-	g_debug( "%s", "" );
 }
