@@ -33,20 +33,23 @@
 #endif
 
 #include <api/na-data-types.h>
+#include <api/na-core-utils.h>
 
 typedef struct {
 	guint  type;
 	gchar *gconf_dump_key;
+	gchar *gconf_secondary_key;
 }
 	FactoryType;
 
 static FactoryType st_factory_type[] = {
-		{ NAFD_TYPE_STRING,        "string" },
-		{ NAFD_TYPE_LOCALE_STRING, "string" },
-		{ NAFD_TYPE_BOOLEAN,       "bool" },
-		{ NAFD_TYPE_STRING_LIST,   "list" },
-		{ NAFD_TYPE_POINTER,        NULL },
-		{ NAFD_TYPE_UINT,          "int" },
+		{ NA_DATA_TYPE_BOOLEAN,       "bool",   NULL },
+		{ NA_DATA_TYPE_POINTER,        NULL,    NULL },
+		{ NA_DATA_TYPE_STRING,        "string", NULL },
+		{ NA_DATA_TYPE_STRING_LIST,   "list",   "string" },
+		{ NA_DATA_TYPE_LOCALE_STRING, "string", NULL },
+		{ NA_DATA_TYPE_UINT,          "int",    NULL },
+		{ NA_DATA_TYPE_UINT_LIST,     "list",   "int" },
 		{ 0 }
 };
 
@@ -64,6 +67,7 @@ static FactoryType st_factory_type[] = {
 const gchar *
 na_data_types_get_gconf_dump_key( guint type )
 {
+	static const gchar *thisfn = "na_data_types_get_gconf_dump_key";
 	FactoryType *str;
 
 	str = st_factory_type;
@@ -74,5 +78,6 @@ na_data_types_get_gconf_dump_key( guint type )
 		str++;
 	}
 
+	g_warning( "%s: unknown data type: %d", thisfn, type );
 	return( NULL );
 }
