@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -40,14 +40,14 @@
 
 G_BEGIN_DECLS
 
-#define NA_EXPORT_FORMAT_TYPE                   ( na_export_format_get_type())
-#define NA_EXPORT_FORMAT( object )              ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_EXPORT_FORMAT_TYPE, NAExportFormat ))
-#define NA_EXPORT_FORMAT_CLASS( klass )         ( G_TYPE_CHECK_CLASS_CAST( klass, NA_EXPORT_FORMAT_TYPE, NAExportFormatClass ))
-#define NA_IS_EXPORT_FORMAT( object )           ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_EXPORT_FORMAT_TYPE ))
-#define NA_IS_EXPORT_FORMAT_CLASS( klass )      ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_EXPORT_FORMAT_TYPE ))
-#define NA_EXPORT_FORMAT_GET_CLASS( object )    ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_EXPORT_FORMAT_TYPE, NAExportFormatClass ))
+#define NA_EXPORT_FORMAT_TYPE                ( na_export_format_get_type())
+#define NA_EXPORT_FORMAT( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_EXPORT_FORMAT_TYPE, NAExportFormat ))
+#define NA_EXPORT_FORMAT_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, NA_EXPORT_FORMAT_TYPE, NAExportFormatClass ))
+#define NA_IS_EXPORT_FORMAT( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_EXPORT_FORMAT_TYPE ))
+#define NA_IS_EXPORT_FORMAT_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_EXPORT_FORMAT_TYPE ))
+#define NA_EXPORT_FORMAT_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_EXPORT_FORMAT_TYPE, NAExportFormatClass ))
 
-typedef struct _NAExportFormatPrivate      NAExportFormatPrivate;
+typedef struct _NAExportFormatPrivate        NAExportFormatPrivate;
 
 typedef struct {
 	GObject                parent;
@@ -55,7 +55,7 @@ typedef struct {
 }
 	NAExportFormat;
 
-typedef struct _NAExportFormatClassPrivate NAExportFormatClassPrivate;
+typedef struct _NAExportFormatClassPrivate   NAExportFormatClassPrivate;
 
 typedef struct {
 	GObjectClass                parent;
@@ -64,6 +64,7 @@ typedef struct {
 	NAExportFormatClass;
 
 #define IPREFS_EXPORT_FORMAT_ASK		g_quark_from_static_string( "Ask" )
+#define IPREFS_EXPORT_NO_EXPORT			1
 
 GType           na_export_format_get_type( void );
 
