@@ -325,15 +325,12 @@ na_factory_object_set_defaults( NAIFactoryObject *object )
 static gboolean
 set_defaults_iter( NADataDef *def, NafoDefaultIter *data )
 {
-	NADataBoxed *boxed;
-	gboolean is_null;
+	NADataBoxed *boxed = na_ifactory_object_get_data_boxed( data->object, def->name );
 
-	is_null = TRUE;
-	boxed = na_ifactory_object_get_data_boxed( data->object, def->name );
 	if( !boxed ){
 		boxed = na_data_boxed_new( def );
 		attach_boxed_to_object( data->object, boxed );
-		na_data_boxed_set_from_string( boxed, def->default_value );
+		na_boxed_set_from_string( NA_BOXED( boxed ), def->default_value );
 	}
 
 	/* do not stop */
@@ -365,7 +362,7 @@ na_factory_object_move_boxed( NAIFactoryObject *target, const NAIFactoryObject *
 
 			attach_boxed_to_object( target, boxed );
 
-			NADataDef *src_def = na_data_boxed_get_data_def( boxed );
+			const NADataDef *src_def = na_data_boxed_get_data_def( boxed );
 			NADataDef *tgt_def = na_factory_object_get_data_def( target, src_def->name );
 			na_data_boxed_set_data_def( boxed, tgt_def );
 		}
@@ -398,7 +395,7 @@ na_factory_object_copy( NAIFactoryObject *target, const NAIFactoryObject *source
 	for( isrc = src_list ; isrc ; isrc = isrc->next ){
 
 		NADataBoxed *src_boxed = NA_DATA_BOXED( isrc->data );
-		NADataDef *def = na_data_boxed_get_data_def( src_boxed );
+		const NADataDef *def = na_data_boxed_get_data_def( src_boxed );
 
 		if( def->copyable ){
 			NADataBoxed *tgt_boxed = na_ifactory_object_get_data_boxed( target, def->name );
@@ -406,7 +403,7 @@ na_factory_object_copy( NAIFactoryObject *target, const NAIFactoryObject *source
 				tgt_boxed = na_data_boxed_new( def );
 				attach_boxed_to_object( target, tgt_boxed );
 			}
-			na_data_boxed_set_from_boxed( tgt_boxed, src_boxed );
+			na_boxed_set_from_boxed( NA_BOXED( tgt_boxed ), NA_BOXED( src_boxed ));
 		}
 	}
 
@@ -415,8 +412,8 @@ na_factory_object_copy( NAIFactoryObject *target, const NAIFactoryObject *source
 
 /*
  * na_factory_object_are_equal:
- * @a: the first #NAIFactoryObject instance.
- * @b: the second #NAIFactoryObject isntance.
+ * @a: the first (original) #NAIFactoryObject instance.
+ * @b: the second (current) #NAIFactoryObject isntance.
  *
  * Returns: %TRUE if @a is equal to @b, %FALSE else.
  */
@@ -432,27 +429,25 @@ na_factory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *
 	a_list = g_object_get_data( G_OBJECT( a ), NA_IFACTORY_OBJECT_PROP_DATA );
 	b_list = g_object_get_data( G_OBJECT( b ), NA_IFACTORY_OBJECT_PROP_DATA );
 
+	g_debug( "%s: a=%p, b=%p", thisfn, ( void * ) a, ( void * ) b );
+
 	are_equal = TRUE;
 	for( ia = a_list ; ia && are_equal ; ia = ia->next ){
 
 		NADataBoxed *a_boxed = NA_DATA_BOXED( ia->data );
-		NADataDef *a_def = na_data_boxed_get_data_def( a_boxed );
+		const NADataDef *a_def = na_data_boxed_get_data_def( a_boxed );
 		if( a_def->comparable ){
 
 			NADataBoxed *b_boxed = na_ifactory_object_get_data_boxed( b, a_def->name );
 			if( b_boxed ){
-				are_equal = na_data_boxed_are_equal( a_boxed, b_boxed );
+				are_equal = na_boxed_are_equal( NA_BOXED( a_boxed ), NA_BOXED( b_boxed ));
 				if( !are_equal ){
 					g_debug( "%s: %s not equal as %s different", thisfn, G_OBJECT_TYPE_NAME( a ), a_def->name );
-					g_debug( "%s: a=", thisfn );
-					na_data_boxed_dump( a_boxed );
-					g_debug( "%s: b=", thisfn );
-					na_data_boxed_dump( b_boxed );
 				}
 
 			} else {
 				are_equal = FALSE;
-				g_debug( "%s: %s not equal as %s not set", thisfn, G_OBJECT_TYPE_NAME( a ), a_def->name );
+				g_debug( "%s: %s not equal as %s has disappeared", thisfn, G_OBJECT_TYPE_NAME( a ), a_def->name );
 			}
 		}
 	}
@@ -460,26 +455,18 @@ na_factory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *
 	for( ib = b_list ; ib && are_equal ; ib = ib->next ){
 
 		NADataBoxed *b_boxed = NA_DATA_BOXED( ib->data );
-		NADataDef *b_def = na_data_boxed_get_data_def( b_boxed );
+		const NADataDef *b_def = na_data_boxed_get_data_def( b_boxed );
 		if( b_def->comparable ){
 
 			NADataBoxed *a_boxed = na_ifactory_object_get_data_boxed( a, b_def->name );
-			if( a_boxed ){
-				are_equal = na_data_boxed_are_equal( a_boxed, b_boxed );
-				if( !are_equal ){
-					g_debug( "%s: %s not equal as %s different", thisfn, G_OBJECT_TYPE_NAME( a ), b_def->name );
-				}
-
-			} else {
+			if( !a_boxed ){
 				are_equal = FALSE;
-				g_debug( "%s: %s not equal as %s not set", thisfn, G_OBJECT_TYPE_NAME( a ), b_def->name );
+				g_debug( "%s: %s not equal as %s was not set", thisfn, G_OBJECT_TYPE_NAME( a ), b_def->name );
 			}
 		}
 	}
 
-	if( are_equal ){
-		are_equal = v_are_equal( a, b );
-	}
+	are_equal &= v_are_equal( a, b );
 
 	return( are_equal );
 }
@@ -493,16 +480,19 @@ na_factory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *
 gboolean
 na_factory_object_is_valid( const NAIFactoryObject *object )
 {
+	static const gchar *thisfn = "na_factory_object_is_valid";
 	gboolean is_valid;
 	NADataGroup *groups;
 	GList *list, *iv;
 
 	g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), FALSE );
 
+	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 	list = g_object_get_data( G_OBJECT( object ), NA_IFACTORY_OBJECT_PROP_DATA );
 	is_valid = TRUE;
 
-	/* mndatory data must be set
+	/* mandatory data must be set
 	 */
 	NafoValidIter iter_data;
 	iter_data.object = ( NAIFactoryObject * ) object;
@@ -518,9 +508,7 @@ na_factory_object_is_valid( const NAIFactoryObject *object )
 		is_valid = na_data_boxed_is_valid( NA_DATA_BOXED( iv->data ));
 	}
 
-	if( is_valid ){
-		is_valid = v_is_valid( object );
-	}
+	is_valid &= v_is_valid( object );
 
 	return( is_valid );
 }
@@ -563,7 +551,7 @@ na_factory_object_dump( const NAIFactoryObject *object )
 
 	for( it = list ; it ; it = it->next ){
 		NADataBoxed *boxed = NA_DATA_BOXED( it->data );
-		NADataDef *def = na_data_boxed_get_data_def( boxed );
+		const NADataDef *def = na_data_boxed_get_data_def( boxed );
 		length = MAX( length, strlen( def->name ));
 	}
 
@@ -571,11 +559,10 @@ na_factory_object_dump( const NAIFactoryObject *object )
 	length += 1;
 
 	for( it = list ; it ; it = it->next ){
-		/*na_data_boxed_dump( NA_DATA_BOXED( it->data ));*/
 		NADataBoxed *boxed = NA_DATA_BOXED( it->data );
-		NADataDef *def = na_data_boxed_get_data_def( boxed );
-		gchar *value = na_data_boxed_get_as_string( boxed );
-		g_debug( "%s: %*s=%s", thisfn, length, def->name+l_prefix, value );
+		const NADataDef *def = na_data_boxed_get_data_def( boxed );
+		gchar *value = na_boxed_get_string( NA_BOXED( boxed ));
+		g_debug( "| %s: %*s=%s", thisfn, length, def->name+l_prefix, value );
 		g_free( value );
 	}
 }
@@ -649,7 +636,7 @@ read_data_iter( NADataDef *def, NafoReadIter *iter )
 		NADataBoxed *exist = na_ifactory_object_get_data_boxed( iter->object, def->name );
 
 		if( exist ){
-			na_data_boxed_set_from_boxed( exist, boxed );
+			na_boxed_set_from_boxed( NA_BOXED( exist ), NA_BOXED( boxed ));
 			g_object_unref( boxed );
 
 		} else {
@@ -721,7 +708,7 @@ na_factory_object_write_item( NAIFactoryObject *object, const NAIFactoryProvider
 static gboolean
 write_data_iter( const NAIFactoryObject *object, NADataBoxed *boxed, NafoWriteIter *iter )
 {
-	NADataDef *def = na_data_boxed_get_data_def( boxed );
+	const NADataDef *def = na_data_boxed_get_data_def( boxed );
 
 	if( def->writable ){
 		iter->code = na_factory_provider_write_data( iter->writer, iter->writer_data, object, boxed, iter->messages );
@@ -740,7 +727,7 @@ write_data_iter( const NAIFactoryObject *object, NADataBoxed *boxed, NafoWriteIt
  * Set the @value with the current content of the #NADataBoxed attached
  * to @name.
  *
- * This is to be readen as "set value from data element".
+ * This is to be read as "set value from data element".
  */
 void
 na_factory_object_get_as_value( const NAIFactoryObject *object, const gchar *name, GValue *value )
@@ -753,7 +740,7 @@ na_factory_object_get_as_value( const NAIFactoryObject *object, const gchar *nam
 
 	boxed = na_ifactory_object_get_data_boxed( object, name );
 	if( boxed ){
-		na_data_boxed_get_as_value( boxed, value );
+		na_boxed_get_as_value( NA_BOXED( boxed ), value );
 	}
 }
 
@@ -764,8 +751,8 @@ na_factory_object_get_as_value( const NAIFactoryObject *object, const gchar *nam
  *
  * Returns: the searched value.
  *
- * If the type of the value is NAFD_TYPE_STRING, NAFD_TYPE_LOCALE_STRING,
- * or NAFD_TYPE_STRING_LIST, then the returned value is a newly allocated
+ * If the type of the value is NA_DATA_TYPE_STRING, NA_DATA_TYPE_LOCALE_STRING,
+ * or NA_DATA_TYPE_STRING_LIST, then the returned value is a newly allocated
  * one and should be g_free() (resp. na_core_utils_slist_free()) by the
  * caller.
  */
@@ -781,7 +768,7 @@ na_factory_object_get_as_void( const NAIFactoryObject *object, const gchar *name
 
 	boxed = na_ifactory_object_get_data_boxed( object, name );
 	if( boxed ){
-		value = na_data_boxed_get_as_void( boxed );
+		value = na_boxed_get_as_void( NA_BOXED( boxed ));
 	}
 
 	return( value );
@@ -805,7 +792,7 @@ na_factory_object_set_from_value( NAIFactoryObject *object, const gchar *name, c
 
 	NADataBoxed *boxed = na_ifactory_object_get_data_boxed( object, name );
 	if( boxed ){
-		na_data_boxed_set_from_value( boxed, value );
+		na_boxed_set_from_value( NA_BOXED( boxed ), value );
 
 	} else {
 		NADataDef *def = na_factory_object_get_data_def( object, name );
@@ -814,7 +801,7 @@ na_factory_object_set_from_value( NAIFactoryObject *object, const gchar *name, c
 
 		} else {
 			boxed = na_data_boxed_new( def );
-			na_data_boxed_set_from_value( boxed, value );
+			na_boxed_set_from_value( NA_BOXED( boxed ), value );
 			attach_boxed_to_object( object, boxed );
 		}
 	}
@@ -837,7 +824,7 @@ na_factory_object_set_from_void( NAIFactoryObject *object, const gchar *name, co
 
 	NADataBoxed *boxed = na_ifactory_object_get_data_boxed( object, name );
 	if( boxed ){
-		na_data_boxed_set_from_void( boxed, data );
+		na_boxed_set_from_void( NA_BOXED( boxed ), data );
 
 	} else {
 		NADataDef *def = na_factory_object_get_data_def( object, name );
@@ -846,7 +833,7 @@ na_factory_object_set_from_void( NAIFactoryObject *object, const gchar *name, co
 
 		} else {
 			boxed = na_data_boxed_new( def );
-			na_data_boxed_set_from_void( boxed, data );
+			na_boxed_set_from_void( NA_BOXED( boxed ), data );
 			attach_boxed_to_object( object, boxed );
 		}
 	}
@@ -855,15 +842,11 @@ na_factory_object_set_from_void( NAIFactoryObject *object, const gchar *name, co
 static NADataGroup *
 v_get_groups( const NAIFactoryObject *object )
 {
-	NADataGroup *groups;
-
-	groups = NULL;
-
 	if( NA_IFACTORY_OBJECT_GET_INTERFACE( object )->get_groups ){
-		groups = NA_IFACTORY_OBJECT_GET_INTERFACE( object )->get_groups( object );
+		return( NA_IFACTORY_OBJECT_GET_INTERFACE( object )->get_groups( object ));
 	}
 
-	return( groups );
+	return( NULL );
 }
 
 static void
@@ -877,29 +860,21 @@ v_copy( NAIFactoryObject *target, const NAIFactoryObject *source )
 static gboolean
 v_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *b )
 {
-	gboolean are_equal;
-
-	are_equal = TRUE;
-
 	if( NA_IFACTORY_OBJECT_GET_INTERFACE( a )->are_equal ){
-		are_equal = NA_IFACTORY_OBJECT_GET_INTERFACE( a )->are_equal( a, b );
+		return( NA_IFACTORY_OBJECT_GET_INTERFACE( a )->are_equal( a, b ));
 	}
 
-	return( are_equal );
+	return( TRUE );
 }
 
 static gboolean
 v_is_valid( const NAIFactoryObject *object )
 {
-	gboolean is_valid;
-
-	is_valid = TRUE;
-
 	if( NA_IFACTORY_OBJECT_GET_INTERFACE( object )->is_valid ){
-		is_valid = NA_IFACTORY_OBJECT_GET_INTERFACE( object )->is_valid( object );
+		return( NA_IFACTORY_OBJECT_GET_INTERFACE( object )->is_valid( object ));
 	}
 
-	return( is_valid );
+	return( TRUE );
 }
 
 static void
