@@ -45,16 +45,16 @@ NADataDef data_def_conditions [] = {
 				TRUE,
 				TRUE,
 				N_( "List of patterns to be matched against the selected file(s)/folder(s)" ),
-				/* i18n: wildcard characters '*' and '?' should be considered as literalls,
+				/* i18n: wildcard characters '*' and '?' should be considered as literals,
 				 *  and not be translated */
 				N_( "A list of strings with joker '*' or '?' to be matched against the name(s) " \
-					"of the selected file(s)/folder(s). Each selected items must match at least " \
+					"of the selected file(s)/folder(s). Each selected item must match at least " \
 					"one of the filename patterns for the action or the menu be candidate to " \
 					"display.\n" \
 					"This obviously only applies when there is a selection.\n" \
 					"Defaults to '*'." ),
-				NAFD_TYPE_STRING_LIST,
-				"[*]",
+				NA_DATA_TYPE_STRING_LIST,
+				"*",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -87,7 +87,7 @@ NADataDef data_def_conditions [] = {
 					"then set 'false'.\n" \
 					"This obviously only applies when there is a selection.\n" \
 					"Defaults to 'true'." ),
-				NAFD_TYPE_BOOLEAN,
+				NA_DATA_TYPE_BOOLEAN,
 				"true",
 				FALSE,
 				TRUE,
@@ -110,12 +110,12 @@ NADataDef data_def_conditions [] = {
 				N_( "List of patterns to be matched against the mimetypes of the selected file(s)/folder(s)" ),
 				/* i18n: wildcard character '*' is taken literally, and should not be translated */
 				N_( "A list of strings with joker '*' to be matched against the mimetypes of the " \
-					"selected file(s)/folder(s). Each selected items must match at least one of " \
+					"selected file(s)/folder(s). Each selected item must match at least one of " \
 					"the mimetype patterns for the action to appear.\n" \
 					"This obviously only applies when there is a selection.\n" \
 					"Defaults to '*/*'." ),
-				NAFD_TYPE_STRING_LIST,
-				"[*/*]",
+				NA_DATA_TYPE_STRING_LIST,
+				"*/*",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -134,12 +134,14 @@ NADataDef data_def_conditions [] = {
 				/* i18n: "<EXPR>" is just an abbreviation for "an expression", so is tranlatable */
 				N_( "<EXPR>" ) },
 
-	/* a runtime boolean set to TRUE if we detect that the previous string list
-	 * just cover all mimetypes - this let us optimize the check for candidate
-	 * in the menu plugin
-	 * when FALSE, than we have to check each and every mimetype :(
+	/* A runtime boolean set to TRUE if we detect that the previous string list
+	 * just cover all mimetypes: this let us optimize the check for candidates
+	 * in the menu plugin.
+	 * When FALSE, than we have to check each and every mimetype :(
+	 * This value is set when loading a pre-v3 profile, and then reset each time
+	 * we update the list of mimetypes.
 	 */
-	{ NAFO_DATA_ALL_MIMETYPES,
+	{ NAFO_DATA_MIMETYPES_IS_ALL,
 				FALSE,
 				FALSE,
 				TRUE,
@@ -147,7 +149,7 @@ NADataDef data_def_conditions [] = {
 				"The generic wildcard may be coded as '*', or '*/*' or 'all' or 'all/*' or 'all/all'. "
 				"In each case, we will try to spend as less time as possible to check " \
 				"selection mimetypes",
-				NAFD_TYPE_BOOLEAN,
+				NA_DATA_TYPE_BOOLEAN,
 				"true",
 				FALSE,
 				TRUE,
@@ -163,11 +165,14 @@ NADataDef data_def_conditions [] = {
 				NULL,
 				NULL },
 
+	/* this is obsoleted starting with 2.30-newdata (released as 2.31.x serie)
+	 * and replaced by mimetypes
+	 */
 	{ NAFO_DATA_ISFILE,
 				TRUE,
+				FALSE,
 				TRUE,
-				TRUE,
-				N_( "Whether the profile applies to files" ),
+				N_( "Whether the profile applies to files (deprecated option, see mimetype)" ),
 				/* i18n: 'true' and 'false' values are taken literally, and should not be translated */
 				N_( "Set to 'true' if the selection can have files, to 'false' otherwise.\n" \
 					"This setting is tied in with the 'isdir' setting. The valid combinations are: \n" \
@@ -178,7 +183,7 @@ NADataDef data_def_conditions [] = {
 					"(your configuration will never appear).\n" \
 					"This obviously only applies when there is a selection.\n" \
 					"Defaults to 'true'." ),
-				NAFD_TYPE_BOOLEAN,
+				NA_DATA_TYPE_BOOLEAN,
 				"true",
 				FALSE,
 				TRUE,
@@ -196,9 +201,9 @@ NADataDef data_def_conditions [] = {
 
 	{ NAFO_DATA_ISDIR,
 				TRUE,
+				FALSE,
 				TRUE,
-				TRUE,
-				N_( "Whether the profile applies to folders" ),
+				N_( "Whether the profile applies to folders (deprecated option, see mimetype)" ),
 				/* i18n: 'true' and 'false' values are taken literally, and should not be translated */
 				N_( "Set to 'true' if the selection can have folders, to 'false' otherwise.\n" \
 					"This setting is tied in with the 'isfile' setting. The valid combinations are: \n" \
@@ -209,7 +214,7 @@ NADataDef data_def_conditions [] = {
 					"(your configuration will never appear).\n" \
 					"This obviously only applies when there is a selection.\n" \
 					"Defaults to 'false'." ),
-				NAFD_TYPE_BOOLEAN,
+				NA_DATA_TYPE_BOOLEAN,
 				"false",
 				FALSE,
 				TRUE,
@@ -232,13 +237,13 @@ NADataDef data_def_conditions [] = {
 				TRUE,
 				FALSE,
 				FALSE,
-				N_( "Whether the selection may be multiple" ),
+				N_( "Whether the selection may be multiple (deprecated option, see selection count)" ),
 				/* i18n: 'true' and 'false' values are taken literally, and should not be translated */
 				N_( "If you need more than one files or folders to be selected, set this " \
 					"key to 'true'. If you want just one file or folder, set it to 'false'.\n" \
 					"This obviously only applies when there is a selection.\n" \
 					"Defaults to 'false'." ),
-				NAFD_TYPE_BOOLEAN,
+				NA_DATA_TYPE_BOOLEAN,
 				"false",
 				FALSE,
 				FALSE,
@@ -247,8 +252,8 @@ NADataDef data_def_conditions [] = {
 				FALSE,
 				"accept-multiple-files",
 				NULL,
-				0,
-				NULL,
+				'u',
+				"accept-multiple",
 				0,
 				G_OPTION_ARG_NONE,
 				NULL,
@@ -278,8 +283,8 @@ NADataDef data_def_conditions [] = {
 					"This obviously only applies when there is a selection, " \
 					"or when targeting the special 'x-nautilus-desktop' scheme.\n" \
 					"Defaults to 'file'." ),
-				NAFD_TYPE_STRING_LIST,
-				"[*]",
+				NA_DATA_TYPE_STRING_LIST,
+				"*",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -290,7 +295,7 @@ NADataDef data_def_conditions [] = {
 				's',
 				"scheme",
 				0,
-				G_OPTION_ARG_STRING,
+				G_OPTION_ARG_STRING_ARRAY,
 				N_( "A valid GIO scheme where the selected file(s)/folder(s) should be located. " \
 					"You must set one option for each scheme you need" ),
 				/* i18n: "<STRING>" is just an abbreviation for "a string", so is tranlatable */
@@ -304,8 +309,8 @@ NADataDef data_def_conditions [] = {
 				N_( "Defines the list of valid paths to be matched against the current folder.\n " \
 					"All folders 'under' the specified path are considered valid.\n" \
 					"Defaults to '/'." ),
-				NAFD_TYPE_STRING_LIST,
-				"[/]",
+				NA_DATA_TYPE_STRING_LIST,
+				"/",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -316,7 +321,7 @@ NADataDef data_def_conditions [] = {
 				'r',
 				"folder",
 				0,
-				G_OPTION_ARG_STRING,
+				G_OPTION_ARG_STRING_ARRAY,
 				N_( "The path of a (parent) directory for which the item will be displayed. " \
 					"You must set one option for each folder you need" ),
 				/* i18n: "<PATH>" is just an abbreviation for "a folder path", so is tranlatable */
@@ -331,7 +336,7 @@ NADataDef data_def_conditions [] = {
 					"This is a string of the form \"{'<'|'='|'>'} number\".\n" \
 					"Examples of valid strings are: \"=0\", \"> 1\", \"< 10\".\n" \
 					"Defaults to \">0\"." ),
-				NAFD_TYPE_STRING,
+				NA_DATA_TYPE_STRING,
 				">0",
 				FALSE,
 				TRUE,
@@ -340,12 +345,13 @@ NADataDef data_def_conditions [] = {
 				FALSE,
 				"selection-count",
 				"SelectionCount",
+				'c',
+				"selection-count",
 				0,
-				NULL,
-				0,
-				G_OPTION_ARG_NONE,
-				NULL,
-				NULL },
+				G_OPTION_ARG_STRING,
+				N_( "Selection count relation [>0]" ),
+				/* i18n: "<EXPR>" is just an abbreviation for "an expression", so is tranlatable */
+				N_( "<EXPR>" ) },
 
 	{ NAFO_DATA_ONLY_SHOW,
 				TRUE,
@@ -353,8 +359,8 @@ NADataDef data_def_conditions [] = {
 				TRUE,
 				N_( "Only show in environment" ),
 				N_( "Defaults to all." ),
-				NAFD_TYPE_STRING_LIST,
-				NULL,
+				NA_DATA_TYPE_STRING_LIST,
+				"",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -362,12 +368,14 @@ NADataDef data_def_conditions [] = {
 				FALSE,
 				"only-show-in",
 				"OnlyShowIn",
+				'y',
+				"only-show-in",
 				0,
-				NULL,
-				0,
-				G_OPTION_ARG_NONE,
-				NULL,
-				NULL },
+				G_OPTION_ARG_STRING_ARRAY,
+				N_( "The name of an only desktop environment where the item must be displayed. " \
+					"You must set one option for each environment you want" ),
+				/* i18n: "<DESKTOP>" is just a placeholder for "a desktop name", so is tranlatable */
+				N_( "<DESKTOP>" ) },
 
 	{ NAFO_DATA_NOT_SHOW,
 				TRUE,
@@ -375,8 +383,8 @@ NADataDef data_def_conditions [] = {
 				TRUE,
 				N_( "Not show in environment" ),
 				N_( "Defaults to none." ),
-				NAFD_TYPE_STRING_LIST,
-				NULL,
+				NA_DATA_TYPE_STRING_LIST,
+				"",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -384,12 +392,14 @@ NADataDef data_def_conditions [] = {
 				FALSE,
 				"not-show-in",
 				"NotShowIn",
+				'Y',
+				"not-show-in",
 				0,
-				NULL,
-				0,
-				G_OPTION_ARG_NONE,
-				NULL,
-				NULL },
+				G_OPTION_ARG_STRING_ARRAY,
+				N_( "The name of a desktop environment where the item must not be displayed. " \
+					"You must set one option for each environment you want" ),
+				/* i18n: "<DESKTOP>" is just a placeholder for "a desktop name", so is tranlatable */
+				N_( "<DESKTOP>" ) },
 
 	{ NAFO_DATA_TRY_EXEC,
 				TRUE,
@@ -401,8 +411,8 @@ NADataDef data_def_conditions [] = {
 					"the specified file are checked.\n" \
 					"Parameters may appear in 'TryExec' value, and will be substituted at runtime.\n" \
 					"Defaults to successful." ),
-				NAFD_TYPE_STRING,
-				NULL,
+				NA_DATA_TYPE_STRING,
+				"",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -410,12 +420,13 @@ NADataDef data_def_conditions [] = {
 				FALSE,
 				"try-exec",
 				"TryExec",
+				'X',
+				"try-exec",
 				0,
-				NULL,
-				0,
-				G_OPTION_ARG_NONE,
-				NULL,
-				NULL },
+				G_OPTION_ARG_STRING,
+				N_( "the path to a file whose executability is to be checked" ),
+				/* i18n: "<PATH>" is the path to a binary, so may be tranlatable */
+				N_( "<PATH>" ) },
 
 	{ NAFO_DATA_SHOW_IF_REGISTERED,
 				TRUE,
@@ -427,8 +438,8 @@ NADataDef data_def_conditions [] = {
 					"The item will be candidate if the named service is registered on session DBus at runtime.\n" \
 					"Parameters may appear in 'ShowIfRegistered' value, and will be substituted at runtime.\n" \
 					"Defaults to successful." ),
-				NAFD_TYPE_STRING,
-				NULL,
+				NA_DATA_TYPE_STRING,
+				"",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -436,12 +447,12 @@ NADataDef data_def_conditions [] = {
 				FALSE,
 				"show-if-registered",
 				"ShowIfRegistered",
+				'g',
+				"show-if-registered",
 				0,
-				NULL,
-				0,
-				G_OPTION_ARG_NONE,
-				NULL,
-				NULL },
+				G_OPTION_ARG_STRING,
+				N_( "The name of a service which must be registered on session DBus" ),
+				N_( "<NAME>" ) },
 
 	{ NAFO_DATA_SHOW_IF_TRUE,
 				TRUE,
@@ -453,8 +464,8 @@ NADataDef data_def_conditions [] = {
 					"The item will be candidate if the outputed string is equal to \"true\".\n" \
 					"Parameters may appear in 'ShowIfTrue' value, and will be substituted at runtime.\n" \
 					"Defaults to successful." ),
-				NAFD_TYPE_STRING,
-				NULL,
+				NA_DATA_TYPE_STRING,
+				"",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -462,12 +473,13 @@ NADataDef data_def_conditions [] = {
 				FALSE,
 				"show-if-true",
 				"ShowIfTrue",
+				'U',
+				"show-if-true",
 				0,
-				NULL,
-				0,
-				G_OPTION_ARG_NONE,
-				NULL,
-				NULL },
+				G_OPTION_ARG_STRING,
+				/* i18n: 'true' is to be taken as a literal, must not be translated */
+				N_( "The path to a command which will display the 'true' string" ),
+				N_( "<PATH>" ) },
 
 	{ NAFO_DATA_SHOW_IF_RUNNING,
 				TRUE,
@@ -479,8 +491,8 @@ NADataDef data_def_conditions [] = {
 					"The item will be candidate if the process name is found in memory at runtime.\n" \
 					"Parameters may appear in 'ShowIfRunning' value, and will be substituted at runtime.\n" \
 					"Defaults to successful." ),
-				NAFD_TYPE_STRING,
-				NULL,
+				NA_DATA_TYPE_STRING,
+				"",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -488,12 +500,12 @@ NADataDef data_def_conditions [] = {
 				FALSE,
 				"show-if-running",
 				"ShowIfRunning",
+				'R',
+				"show-if-running",
 				0,
-				NULL,
-				0,
-				G_OPTION_ARG_NONE,
-				NULL,
-				NULL },
+				G_OPTION_ARG_STRING,
+				N_( "The name of a binary which must be running" ),
+				N_( "<NAME>" ) },
 
 	{ NAFO_DATA_CAPABILITITES,
 				TRUE,
@@ -501,18 +513,18 @@ NADataDef data_def_conditions [] = {
 				TRUE,
 				N_( "Capabilities" ),
 				/* i18n: 'Owner', 'Readable', 'Writable', 'Executable' and 'Local' are all keywords
-				 *  of the specification, they are not translatable */
-				N_( "A list of capabilities each item of the selection must satisfy in order the item be candidate.\n" \
+				 *  of the specification; they are not translatable */
+				N_( "A list of capabilities each item of the selection must satisfy in order for the item to be candidate.\n" \
 					"Capabilities may be negated.\n" \
-					"Capabilities have to be choosen between following predefined ones:\n" \
+					"Capabilities have to be chosen between following predefined ones:\n" \
 					"- 'Owner': current user is the owner of selected items\n" \
 					"- 'Readable': selected items are readable by user (probably more usefull when negated)\n" \
 					"- 'Writable': selected items are writable by user\n" \
 					"- 'Executable': selected items are executable by user\n" \
 					"- 'Local': selected items are local.\n" \
 					"Defaults to empty list." ),
-				NAFD_TYPE_STRING_LIST,
-				NULL,
+				NA_DATA_TYPE_STRING_LIST,
+				"",
 				FALSE,
 				TRUE,
 				TRUE,
@@ -520,12 +532,13 @@ NADataDef data_def_conditions [] = {
 				FALSE,
 				"capabilities",
 				"Capabilities",
+				'P',
+				"capability",
 				0,
-				NULL,
-				0,
-				G_OPTION_ARG_NONE,
-				NULL,
-				NULL },
+				G_OPTION_ARG_STRING_ARRAY,
+				N_( "The name of a capability the selection must meet. "
+					"May be 'Owner', 'Readable', 'Writable', 'Executable' or 'Local'" ),
+				N_( "<NAME>" ) },
 
 	{ NULL },
 };
