@@ -33,10 +33,10 @@
 
 /* @title: NAImporterAsk
  * @short_description: The #NAImporterAsk Class Definition
- * @include: core/na-iimporter-ask.h
+ * @include: core/na-importer-ask.h
  *
- * This class reates and manages a dialog. It is ran each time an
- * imported action as the same ID as an existing one, and the user
+ * This class creates and manages a dialog. It is ran each time an
+ * imported action as the same Id as an existing one, and the user
  * want to be ask to known what to do with it.
  */
 
@@ -44,16 +44,18 @@
 
 #include <api/na-object-item.h>
 
+#include "na-pivot.h"
+
 G_BEGIN_DECLS
 
-#define NA_IMPORTER_ASK_TYPE                 ( na_importer_ask_get_type())
-#define NA_IMPORTER_ASK( object )            ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_IMPORTER_ASK_TYPE, NAImporterAsk ))
-#define NA_IMPORTER_ASK_CLASS( klass )       ( G_TYPE_CHECK_CLASS_CAST( klass, NA_IMPORTER_ASK_TYPE, NAImporterAskClass ))
-#define NA_IS_IMPORTER_ASK( object )         ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_IMPORTER_ASK_TYPE ))
-#define NA_IS_IMPORTER_ASK_CLASS( klass )    ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_IMPORTER_ASK_TYPE ))
-#define NA_IMPORTER_ASK_GET_CLASS( object )  ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_IMPORTER_ASK_TYPE, NAImporterAskClass ))
+#define NA_IMPORTER_ASK_TYPE                ( na_importer_ask_get_type())
+#define NA_IMPORTER_ASK( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, NA_IMPORTER_ASK_TYPE, NAImporterAsk ))
+#define NA_IMPORTER_ASK_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, NA_IMPORTER_ASK_TYPE, NAImporterAskClass ))
+#define NA_IS_IMPORTER_ASK( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, NA_IMPORTER_ASK_TYPE ))
+#define NA_IS_IMPORTER_ASK_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NA_IMPORTER_ASK_TYPE ))
+#define NA_IMPORTER_ASK_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), NA_IMPORTER_ASK_TYPE, NAImporterAskClass ))
 
-typedef struct _NAImporterAskPrivate      NAImporterAskPrivate;
+typedef struct _NAImporterAskPrivate        NAImporterAskPrivate;
 
 typedef struct {
 	/*< private >*/
@@ -62,7 +64,7 @@ typedef struct {
 }
 	NAImporterAsk;
 
-typedef struct _NAImporterAskClassPrivate NAImporterAskClassPrivate;
+typedef struct _NAImporterAskClassPrivate   NAImporterAskClassPrivate;
 
 typedef struct {
 	/*< private >*/
@@ -72,10 +74,11 @@ typedef struct {
 	NAImporterAskClass;
 
 typedef struct {
-	GtkWindow    *parent;
-	gchar        *uri;
-	guint         count;
-	gboolean      keep_choice;
+	GtkWindow     *parent;
+	gchar         *uri;
+	guint          count;
+	gboolean       keep_choice;
+	const NAPivot *pivot;
 }
 	NAImporterAskUserParms;
 
