@@ -4,7 +4,7 @@
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -33,6 +33,7 @@
 #endif
 
 #include <glib/gi18n.h>
+#include <libintl.h>
 #include <string.h>
 #include <stdlib.h>
 
@@ -45,13 +46,13 @@
 
 /* private class data
  */
-struct NAObjectActionClassPrivate {
+struct _NAObjectActionClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAObjectActionPrivate {
+struct _NAObjectActionPrivate {
 	gboolean dispose_has_run;
 };
 
@@ -71,14 +72,13 @@ static void         instance_set_property( GObject *object, guint property_id, c
 static void         instance_dispose( GObject *object );
 static void         instance_finalize( GObject *object );
 
-static void         object_copy( NAObject *target, const NAObject *source, gboolean recursive );
+static void         object_dump( const NAObject *object );
+static gboolean     object_are_equal( const NAObject *a, const NAObject *b );
 static gboolean     object_is_valid( const NAObject *object );
 
 static void         ifactory_object_iface_init( NAIFactoryObjectInterface *iface );
 static guint        ifactory_object_get_version( const NAIFactoryObject *instance );
 static NADataGroup *ifactory_object_get_groups( const NAIFactoryObject *instance );
-static gboolean     ifactory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *b );
-static gboolean     ifactory_object_is_valid( const NAIFactoryObject *object );
 static void         ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 static guint        ifactory_object_write_start( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
@@ -91,7 +91,6 @@ static void         read_done_deals_with_toolbar_label( NAIFactoryObject *instan
 
 static guint        write_done_write_profiles( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 
-static gboolean     object_object_is_valid( const NAObjectAction *action );
 static gboolean     is_valid_label( const NAObjectAction *action );
 static gboolean     is_valid_toolbar_label( const NAObjectAction *action );
 
@@ -167,9 +166,8 @@ class_init( NAObjectActionClass *klass )
 	object_class->finalize = instance_finalize;
 
 	naobject_class = NA_OBJECT_CLASS( klass );
-	naobject_class->dump = NULL;
-	naobject_class->copy = object_copy;
-	naobject_class->are_equal = NULL;
+	naobject_class->dump = object_dump;
+	naobject_class->are_equal = object_are_equal;
 	naobject_class->is_valid = object_is_valid;
 
 	klass->private = g_new0( NAObjectActionClassPrivate, 1 );
@@ -228,7 +226,6 @@ instance_dispose( GObject *object )
 	self = NA_OBJECT_ACTION( object );
 
 	if( !self->private->dispose_has_run ){
-
 		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
 		self->private->dispose_has_run = TRUE;
@@ -261,24 +258,96 @@ instance_finalize( GObject *object )
 }
 
 static void
-object_copy( NAObject *target, const NAObject *source, gboolean recursive )
+object_dump( const NAObject *object )
 {
-	g_return_if_fail( NA_IS_OBJECT_ACTION( target ));
-	g_return_if_fail( NA_IS_OBJECT_ACTION( source ));
+	static const char *thisfn = "na_object_action_object_dump";
+	NAObjectAction *self;
 
-	if( !NA_OBJECT_ACTION( target )->private->dispose_has_run &&
-		!NA_OBJECT_ACTION( source )->private->dispose_has_run ){
+	g_return_if_fail( NA_IS_OBJECT_ACTION( object ));
 
-		na_factory_object_copy( NA_IFACTORY_OBJECT( target ), NA_IFACTORY_OBJECT( source ));
+	self = NA_OBJECT_ACTION( object );
+
+	if( !self->private->dispose_has_run ){
+		g_debug( "%s: object=%p (%s, ref_count=%d)", thisfn,
+				( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count );
+
+		/* chain up to the parent class */
+		if( NA_OBJECT_CLASS( st_parent_class )->dump ){
+			NA_OBJECT_CLASS( st_parent_class )->dump( object );
+		}
+
+		g_debug( "+- end of dump" );
 	}
 }
 
+/*
+ * @a is the original object
+ * @b is the current one
+ *
+ * Even if they have both the same children list, the current action is
+ * considered modified as soon as one of its profile is itself modified.
+ */
+static gboolean
+object_are_equal( const NAObject *a, const NAObject *b )
+{
+	static const gchar *thisfn = "na_object_action_object_are_equal";
+	GList *it;
+	gboolean are_equal;
+
+	g_debug( "%s: a=%p, b=%p", thisfn, ( void * ) a, ( void * ) b );
+
+	for( it = na_object_get_items( b ) ; it ; it = it->next ){
+		if( na_object_is_modified( it->data )){
+			return( FALSE );
+		}
+	}
+
+	are_equal = TRUE;
+
+	/* chain call to parent class */
+	if( NA_OBJECT_CLASS( st_parent_class )->are_equal ){
+		are_equal &= NA_OBJECT_CLASS( st_parent_class )->are_equal( a, b );
+	}
+
+	return( are_equal );
+}
+
 static gboolean
 object_is_valid( const NAObject *object )
 {
+	static const gchar *thisfn = "na_object_action_object_is_valid";
+	gboolean is_valid;
+	NAObjectAction *action;
+
 	g_return_val_if_fail( NA_IS_OBJECT_ACTION( object ), FALSE );
 
-	return( object_object_is_valid( NA_OBJECT_ACTION( object )));
+	is_valid = FALSE;
+	action = NA_OBJECT_ACTION( object );
+
+	if( !action->private->dispose_has_run ){
+		g_debug( "%s: action=%p (%s)", thisfn, ( void * ) action, G_OBJECT_TYPE_NAME( action ));
+
+		is_valid = TRUE;
+
+		if( na_object_is_target_toolbar( action )){
+			is_valid &= is_valid_toolbar_label( action );
+		}
+
+		if( na_object_is_target_selection( action ) || na_object_is_target_location( action )){
+			is_valid &= is_valid_label( action );
+		}
+
+		if( !is_valid ){
+			na_object_debug_invalid( action, "no valid profile" );
+		}
+	}
+
+	/* chain up to the parent class */
+	if( NA_OBJECT_CLASS( st_parent_class )->is_valid ){
+		is_valid &= NA_OBJECT_CLASS( st_parent_class )->is_valid( object );
+	}
+
+	return( is_valid );
 }
 
 static void
@@ -290,10 +359,6 @@ ifactory_object_iface_init( NAIFactoryObjectInterface *iface )
 
 	iface->get_version = ifactory_object_get_version;
 	iface->get_groups = ifactory_object_get_groups;
-	iface->copy = NULL;
-	iface->are_equal = ifactory_object_are_equal;
-	iface->is_valid = ifactory_object_is_valid;
-	iface->read_start = NULL;
 	iface->read_done = ifactory_object_read_done;
 	iface->write_start = ifactory_object_write_start;
 	iface->write_done = ifactory_object_write_done;
@@ -311,22 +376,8 @@ ifactory_object_get_groups( const NAIFactoryObject *instance )
 	return( action_data_groups );
 }
 
-static gboolean
-ifactory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *b )
-{
-	return( na_object_item_are_equal( NA_OBJECT_ITEM( a ), NA_OBJECT_ITEM( b )));
-}
-
-static gboolean
-ifactory_object_is_valid( const NAIFactoryObject *object )
-{
-	g_return_val_if_fail( NA_IS_OBJECT_ACTION( object ), FALSE );
-
-	return( object_object_is_valid( NA_OBJECT_ACTION( object )));
-}
-
 /*
- * at this time, we don't yet have readen the profiles as this will be
+ * at this time, we don't yet have read the profiles as this will be
  * done in ifactory_provider_read_done - we so just be able to deal with
  * action-specific properties (not check for profiles consistency)
  */
@@ -405,7 +456,7 @@ icontext_is_candidate( NAIContext *object, guint target, GList *selection )
  *  any data found in data_def_action_v1 (defined in na-object-action-factory.c)
  *  is obsoleted and moved to a new profile
  *
- * actions readen from .desktop already have iversion=3 (cf. desktop_read_start)
+ * actions read from .desktop already have iversion=3 (cf. desktop_read_start)
  * and v1 actions may only come from xml or gconf
  *
  * returns TRUE if this actually was a v1 action which has been converted to v2
@@ -514,49 +565,6 @@ write_done_write_profiles( NAIFactoryObject *instance, const NAIFactoryProvider
 	return( code );
 }
 
-static gboolean
-object_object_is_valid( const NAObjectAction *action )
-{
-	gboolean is_valid;
-	GList *profiles, *ip;
-	gint valid_profiles;
-
-	is_valid = FALSE;
-
-	if( !action->private->dispose_has_run ){
-
-		is_valid = TRUE;
-
-		if( is_valid ){
-			if( na_object_is_target_toolbar( action )){
-				is_valid = is_valid_toolbar_label( action );
-			}
-		}
-
-		if( is_valid ){
-			if( na_object_is_target_selection( action )){
-				is_valid = is_valid_label( action );
-			}
-		}
-
-		if( is_valid ){
-			valid_profiles = 0;
-			profiles = na_object_get_items( action );
-			for( ip = profiles ; ip && !valid_profiles ; ip = ip->next ){
-				if( na_object_is_valid( ip->data )){
-					valid_profiles += 1;
-				}
-			}
-			is_valid = ( valid_profiles > 0 );
-			if( !is_valid ){
-				na_object_debug_invalid( action, "no valid profile" );
-			}
-		}
-	}
-
-	return( is_valid );
-}
-
 static gboolean
 is_valid_label( const NAObjectAction *action )
 {
@@ -600,6 +608,8 @@ is_valid_toolbar_label( const NAObjectAction *action )
  * but without any profile.
  *
  * Returns: the newly allocated #NAObjectAction object.
+ *
+ * Since: 2.30
  */
 NAObjectAction *
 na_object_action_new( void )
@@ -617,6 +627,8 @@ na_object_action_new( void )
  * Allocates a new #NAObjectAction object along with a default profile.
  *
  * Returns: the newly allocated #NAObjectAction action.
+ *
+ * Since: 2.30
  */
 NAObjectAction *
 na_object_action_new_with_profile( void )
@@ -638,6 +650,8 @@ na_object_action_new_with_profile( void )
  * These two objects have suitable default values.
  *
  * Returns: the newly allocated #NAObjectAction action.
+ *
+ * Since: 2.30
  */
 NAObjectAction *
 na_object_action_new_with_defaults( void )
@@ -647,8 +661,8 @@ na_object_action_new_with_defaults( void )
 
 	action = na_object_action_new();
 	na_object_set_new_id( action, NULL );
-	na_object_set_label( action, NEW_NAUTILUS_ACTION );
-	na_object_set_toolbar_label( action, NEW_NAUTILUS_ACTION );
+	na_object_set_label( action, gettext( NEW_NAUTILUS_ACTION ));
+	na_object_set_toolbar_label( action, gettext( NEW_NAUTILUS_ACTION ));
 	na_factory_object_set_defaults( NA_IFACTORY_OBJECT( action ));
 
 	profile = na_object_profile_new_with_defaults();
@@ -668,12 +682,14 @@ na_object_action_new_with_defaults( void )
  * which is not yet allocated. The provided name is so only suitable
  * for the specified @action.
  *
- * Returns: a newly allocated profile name, which should be g_free() by
- * the caller.
- *
  * When inserting a list of profiles in the action, we iter first for
  * new names, before actually do the insertion. We so keep the last
  * allocated name to avoid to allocate the same one twice.
+ *
+ * Returns: a newly allocated profile name, which should be g_free() by
+ * the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_object_action_get_new_profile_name( const NAObjectAction *action )
@@ -715,6 +731,8 @@ na_object_action_get_new_profile_name( const NAObjectAction *action )
  * @profile: the #NAObjectProfile profile to be attached to @action.
  *
  * Adds a profile at the end of the list of profiles.
+ *
+ * Since: 2.30
  */
 void
 na_object_action_attach_profile( NAObjectAction *action, NAObjectProfile *profile )
@@ -734,6 +752,8 @@ na_object_action_attach_profile( NAObjectAction *action, NAObjectProfile *profil
  * @action: the #NAObjectAction action to update.
  *
  * Set the version number of the @action to the last one.
+ *
+ * Since: 2.30
  */
 void
 na_object_action_set_last_version( NAObjectAction *action )
