@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -44,13 +44,13 @@
 
 /* private class data
  */
-struct NAObjectMenuClassPrivate {
+struct _NAObjectMenuClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAObjectMenuPrivate {
+struct _NAObjectMenuPrivate {
 	gboolean dispose_has_run;
 };
 
@@ -69,15 +69,11 @@ static void         instance_set_property( GObject *object, guint property_id, c
 static void         instance_dispose( GObject *object );
 static void         instance_finalize( GObject *object );
 
-static void         object_copy( NAObject *target, const NAObject *source, gboolean recursive );
-static gboolean     object_is_valid( const NAObject *object );
+static void         object_dump( const NAObject *object );
 
 static void         ifactory_object_iface_init( NAIFactoryObjectInterface *iface );
 static guint        ifactory_object_get_version( const NAIFactoryObject *instance );
 static NADataGroup *ifactory_object_get_groups( const NAIFactoryObject *instance );
-static gboolean     ifactory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *b );
-static gboolean     ifactory_object_is_valid( const NAIFactoryObject *object );
-static void         ifactory_object_read_start( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 static void         ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 static guint        ifactory_object_write_start( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
@@ -85,9 +81,6 @@ static guint        ifactory_object_write_done( NAIFactoryObject *instance, cons
 static void         icontext_iface_init( NAIContextInterface *iface );
 static gboolean     icontext_is_candidate( NAIContext *object, guint target, GList *selection );
 
-static gboolean     menu_is_valid( const NAObjectMenu *menu );
-static gboolean     is_valid_label( const NAObjectMenu *menu );
-
 GType
 na_object_menu_get_type( void )
 {
@@ -160,10 +153,7 @@ class_init( NAObjectMenuClass *klass )
 	object_class->finalize = instance_finalize;
 
 	naobject_class = NA_OBJECT_CLASS( klass );
-	naobject_class->dump = NULL;
-	naobject_class->copy = object_copy;
-	naobject_class->are_equal = NULL;
-	naobject_class->is_valid = object_is_valid;
+	naobject_class->dump = object_dump;
 
 	klass->private = g_new0( NAObjectMenuClassPrivate, 1 );
 
@@ -254,26 +244,28 @@ instance_finalize( GObject *object )
 }
 
 static void
-object_copy( NAObject *target, const NAObject *source, gboolean recursive )
+object_dump( const NAObject *object )
 {
-	g_return_if_fail( NA_IS_OBJECT_MENU( target ));
-	g_return_if_fail( NA_IS_OBJECT_MENU( source ));
+	static const char *thisfn = "na_object_menu_object_dump";
+	NAObjectMenu *self;
 
-	if( !NA_OBJECT_MENU( target )->private->dispose_has_run &&
-		!NA_OBJECT_MENU( source )->private->dispose_has_run ){
+	g_return_if_fail( NA_IS_OBJECT_MENU( object ));
 
-		na_factory_object_copy( NA_IFACTORY_OBJECT( target ), NA_IFACTORY_OBJECT( source ));
+	self = NA_OBJECT_MENU( object );
+
+	if( !self->private->dispose_has_run ){
+		g_debug( "%s: object=%p (%s, ref_count=%d)", thisfn,
+				( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count );
+
+		/* chain up to the parent class */
+		if( NA_OBJECT_CLASS( st_parent_class )->dump ){
+			NA_OBJECT_CLASS( st_parent_class )->dump( object );
+		}
+
+		g_debug( "+- end of dump" );
 	}
 }
 
-static gboolean
-object_is_valid( const NAObject *object )
-{
-	g_return_val_if_fail( NA_IS_OBJECT_MENU( object ), FALSE );
-
-	return( menu_is_valid( NA_OBJECT_MENU( object )));
-}
-
 static void
 ifactory_object_iface_init( NAIFactoryObjectInterface *iface )
 {
@@ -283,10 +275,6 @@ ifactory_object_iface_init( NAIFactoryObjectInterface *iface )
 
 	iface->get_version = ifactory_object_get_version;
 	iface->get_groups = ifactory_object_get_groups;
-	iface->copy = NULL;
-	iface->are_equal = ifactory_object_are_equal;
-	iface->is_valid = ifactory_object_is_valid;
-	iface->read_start = ifactory_object_read_start;
 	iface->read_done = ifactory_object_read_done;
 	iface->write_start = ifactory_object_write_start;
 	iface->write_done = ifactory_object_write_done;
@@ -304,33 +292,16 @@ ifactory_object_get_groups( const NAIFactoryObject *instance )
 	return( menu_data_groups );
 }
 
-static gboolean
-ifactory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *b )
-{
-	return( na_object_item_are_equal( NA_OBJECT_ITEM( a ), NA_OBJECT_ITEM( b )));
-}
-
-static gboolean
-ifactory_object_is_valid( const NAIFactoryObject *object )
-{
-	g_return_val_if_fail( NA_IS_OBJECT_MENU( object ), FALSE );
-
-	return( menu_is_valid( NA_OBJECT_MENU( object )));
-}
-
-static void
-ifactory_object_read_start( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages )
-{
-}
-
 static void
 ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages )
 {
+	na_object_item_deals_with_version( NA_OBJECT_ITEM( instance ));
+
 	/* prepare the context after the reading
 	 */
 	na_icontext_read_done( NA_ICONTEXT( instance ));
 
-	/* last, set other action defaults
+	/* last, set other menu defaults
 	 */
 	na_factory_object_set_defaults( instance );
 }
@@ -365,64 +336,14 @@ icontext_is_candidate( NAIContext *object, guint target, GList *selection )
 	return( TRUE );
 }
 
-static gboolean
-menu_is_valid( const NAObjectMenu *menu )
-{
-	gboolean is_valid;
-	gint valid_subitems;
-	GList *subitems, *ip;
-
-	is_valid = FALSE;
-
-	if( !menu->private->dispose_has_run ){
-
-		is_valid = TRUE;
-
-		if( is_valid ){
-			is_valid = is_valid_label( menu );
-		}
-
-		if( is_valid ){
-			valid_subitems = 0;
-			subitems = na_object_get_items( menu );
-			for( ip = subitems ; ip && !valid_subitems ; ip = ip->next ){
-				if( na_object_is_valid( ip->data )){
-					valid_subitems += 1;
-				}
-			}
-			is_valid = ( valid_subitems > 0 );
-			if( !is_valid ){
-				na_object_debug_invalid( menu, "no valid subitem" );
-			}
-		}
-	}
-
-	return( is_valid );
-}
-
-static gboolean
-is_valid_label( const NAObjectMenu *menu )
-{
-	gboolean is_valid;
-	gchar *label;
-
-	label = na_object_get_label( menu );
-	is_valid = ( label && g_utf8_strlen( label, -1 ) > 0 );
-	g_free( label );
-
-	if( !is_valid ){
-		na_object_debug_invalid( menu, "label" );
-	}
-
-	return( is_valid );
-}
-
 /**
  * na_object_menu_new:
  *
  * Allocates a new #NAObjectMenu object.
  *
  * Returns: the newly allocated #NAObjectMenu object.
+ *
+ * Since: 2.30
  */
 NAObjectMenu *
 na_object_menu_new( void )
@@ -440,13 +361,15 @@ na_object_menu_new( void )
  * Allocates a new #NAObjectMenu object, and setup default values.
  *
  * Returns: the newly allocated #NAObjectMenu object.
+ *
+ * Since: 2.30
  */
 NAObjectMenu *
 na_object_menu_new_with_defaults( void )
 {
 	NAObjectMenu *menu = na_object_menu_new();
 	na_object_set_new_id( menu, NULL );
-	na_object_set_label( menu, NEW_NAUTILUS_MENU );
+	na_object_set_label( menu, gettext( NEW_NAUTILUS_MENU ));
 	na_factory_object_set_defaults( NA_IFACTORY_OBJECT( menu ));
 
 	return( menu );
