@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -62,6 +62,7 @@ struct _NASelectedInfoPrivate {
 	gboolean       can_write;
 	gboolean       can_execute;
 	gchar         *owner;
+	gboolean       attributes_are_set;
 };
 
 
@@ -76,7 +77,7 @@ static void            instance_finalize( GObject *object );
 static void            dump( const NASelectedInfo *nsi );
 static NASelectedInfo *new_from_nautilus_file_info( NautilusFileInfo *item );
 static NASelectedInfo *new_from_uri( const gchar *uri, const gchar *mimetype, gchar **errmsg );
-static gboolean        query_file_attributes( NASelectedInfo *info, GFile *location, gchar **errmsg );
+static void            query_file_attributes( NASelectedInfo *info, GFile *location, gchar **errmsg );
 
 GType
 na_selected_info_get_type( void )
@@ -139,11 +140,12 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	NASelectedInfo *self;
 
 	g_return_if_fail( NA_IS_SELECTED_INFO( instance ));
-	self = NA_SELECTED_INFO( instance );
 
 	g_debug( "%s: instance=%p (%s), klass=%p",
 			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 
+	self = NA_SELECTED_INFO( instance );
+
 	self->private = g_new0( NASelectedInfoPrivate, 1 );
 
 	self->private->dispose_has_run = FALSE;
@@ -160,7 +162,6 @@ instance_dispose( GObject *object )
 	self = NA_SELECTED_INFO( object );
 
 	if( !self->private->dispose_has_run ){
-
 		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
 		self->private->dispose_has_run = TRUE;
@@ -179,9 +180,10 @@ instance_finalize( GObject *object )
 	NASelectedInfo *self;
 
 	g_return_if_fail( NA_IS_SELECTED_INFO( object ));
+
 	self = NA_SELECTED_INFO( object );
 
-	g_debug( "%s: object=%p", thisfn, ( void * ) object );
+	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
 	g_free( self->private->uri );
 	g_free( self->private->filename );
@@ -525,6 +527,29 @@ na_selected_info_is_directory( const NASelectedInfo *nsi )
 	return( is_dir );
 }
 
+/*
+ * na_selected_info_is_regular:
+ * @nsi: this #NASelectedInfo object.
+ *
+ * Returns: %TRUE if the item is a regular file, %FALSE else.
+ */
+gboolean
+na_selected_info_is_regular( const NASelectedInfo *nsi )
+{
+	gboolean is_regular;
+
+	g_return_val_if_fail( NA_IS_SELECTED_INFO( nsi ), FALSE );
+
+	is_regular = FALSE;
+
+	if( !nsi->private->dispose_has_run ){
+
+		is_regular = ( nsi->private->file_type == G_FILE_TYPE_REGULAR );
+	}
+
+	return( is_regular );
+}
+
 /*
  * na_selected_info_is_executable:
  * @nsi: this #NASelectedInfo object.
@@ -670,19 +695,20 @@ dump( const NASelectedInfo *nsi )
 {
 	static const gchar *thisfn = "na_selected_info_dump";
 
-	g_debug( "%s:         uri=%s", thisfn, nsi->private->uri );
-	g_debug( "%s:    mimetype=%s", thisfn, nsi->private->mimetype );
-	g_debug( "%s:    filename=%s", thisfn, nsi->private->filename );
-	g_debug( "%s:     dirname=%s", thisfn, nsi->private->dirname );
-	g_debug( "%s:    basename=%s", thisfn, nsi->private->basename );
-	g_debug( "%s:    hostname=%s", thisfn, nsi->private->hostname );
-	g_debug( "%s:    username=%s", thisfn, nsi->private->username );
-	g_debug( "%s:      scheme=%s", thisfn, nsi->private->scheme );
-	g_debug( "%s:        port=%d", thisfn, nsi->private->port );
-	g_debug( "%s:    can_read=%s", thisfn, nsi->private->can_read ? "True":"False" );
-	g_debug( "%s:   can_write=%s", thisfn, nsi->private->can_write ? "True":"False" );
-	g_debug( "%s: can_execute=%s", thisfn, nsi->private->can_execute ? "True":"False" );
-	g_debug( "%s:       owner=%s", thisfn, nsi->private->owner );
+	g_debug( "%s:                uri=%s", thisfn, nsi->private->uri );
+	g_debug( "%s:           mimetype=%s", thisfn, nsi->private->mimetype );
+	g_debug( "%s:           filename=%s", thisfn, nsi->private->filename );
+	g_debug( "%s:            dirname=%s", thisfn, nsi->private->dirname );
+	g_debug( "%s:           basename=%s", thisfn, nsi->private->basename );
+	g_debug( "%s:           hostname=%s", thisfn, nsi->private->hostname );
+	g_debug( "%s:           username=%s", thisfn, nsi->private->username );
+	g_debug( "%s:             scheme=%s", thisfn, nsi->private->scheme );
+	g_debug( "%s:               port=%d", thisfn, nsi->private->port );
+	g_debug( "%s:           can_read=%s", thisfn, nsi->private->can_read ? "True":"False" );
+	g_debug( "%s:          can_write=%s", thisfn, nsi->private->can_write ? "True":"False" );
+	g_debug( "%s:        can_execute=%s", thisfn, nsi->private->can_execute ? "True":"False" );
+	g_debug( "%s:              owner=%s", thisfn, nsi->private->owner );
+	g_debug( "%s: attributes_are_set=%s", thisfn, nsi->private->attributes_are_set ? "True":"False" );
 }
 
 static NASelectedInfo *
@@ -698,11 +724,70 @@ new_from_nautilus_file_info( NautilusFileInfo *item )
 	return( info );
 }
 
+/*
+ * Nautilus uses to address the desktop via the 'x-nautilus-desktop:///' URI.
+ * g_filename_from_uri() complains that
+ * "The URI 'x-nautilus-desktop:///' is not an absolute URI using the "file" scheme".
+ * In this case, we prefer the vfs->path member wich is just a decomposition of the
+ * URI, and does not try to interpret it.
+ *
+ * *********************************************************************************
+ * Extract from RFC 2396:
+ *
+ * 2.4.3. Excluded US-ASCII Characters
+ *
+ * Although they are disallowed within the URI syntax, we include here a
+ * description of those US-ASCII characters that have been excluded and
+ * the reasons for their exclusion.
+ *
+ * The control characters in the US-ASCII coded character set are not
+ * used within a URI, both because they are non-printable and because
+ * they are likely to be misinterpreted by some control mechanisms.
+ *
+ * control = <US-ASCII coded characters 00-1F and 7F hexadecimal>
+ *
+ * The space character is excluded because significant spaces may
+ * disappear and insignificant spaces may be introduced when URI are
+ * transcribed or typeset or subjected to the treatment of word-
+ * processing programs. Whitespace is also used to delimit URI in many
+ * contexts.
+ *
+ * space = <US-ASCII coded character 20 hexadecimal>
+ *
+ * The angle-bracket "<" and ">" and double-quote (") characters are
+ * excluded because they are often used as the delimiters around URI in
+ * text documents and protocol fields. The character "#" is excluded
+ * because it is used to delimit a URI from a fragment identifier in URI
+ * references (Section 4). The percent character "%" is excluded because
+ * it is used for the encoding of escaped characters.
+ *
+ * delims = "<" | ">" | "#" | "%" | <">
+ *
+ * Other characters are excluded because gateways and other transport
+ * agents are known to sometimes modify such characters, or they are
+ * used as delimiters.
+ *
+ * unwise = "{" | "}" | "|" | "\" | "^" | "[" | "]" | "`"
+ *
+ * Data corresponding to excluded characters must be escaped in order to
+ * be properly represented within a URI.
+ *
+ * pwi 2011-01-04:
+ *
+ * It results from the above excerpt that:
+ * - as double quotes are not valid character in URI, they have to be
+ *   escaped as %22, and so Nautilus does
+ * - but simple quotes are not forbidden, and so have not to be
+ *   escaped, and so Nautilus does not escape them
+ *
+ * As a result, we may have valid, non-escaped, simple quotes in an URI.
+ */
 static NASelectedInfo *
 new_from_uri( const gchar *uri, const gchar *mimetype, gchar **errmsg )
 {
 	GFile *location;
 	NAGnomeVFSURI *vfs;
+	GError *error;
 
 	NASelectedInfo *info = g_object_new( NA_SELECTED_INFO_TYPE, NULL );
 
@@ -711,12 +796,20 @@ new_from_uri( const gchar *uri, const gchar *mimetype, gchar **errmsg )
 		info->private->mimetype = g_strdup( mimetype );
 	}
 
-	info->private->filename = g_filename_from_uri( uri, NULL, NULL );
-	info->private->dirname = g_path_get_dirname( info->private->filename );
-	info->private->basename = g_path_get_basename( info->private->filename );
-
 	vfs = g_new0( NAGnomeVFSURI, 1 );
 	na_gnome_vfs_uri_parse( vfs, uri );
+	error = NULL;
+	info->private->filename = g_filename_from_uri( uri, NULL, &error );
+	if( error ){
+		g_debug( "new_from_uri: uri='%s', error=%s", uri, error->message );
+		g_error_free( error );
+	}
+	if( !info->private->filename ){
+		g_debug( "new_from_uri: uri='%s', filename=NULL, setting it to '%s'", uri, vfs->path );
+		info->private->filename = g_strdup( vfs->path );
+	}
+	info->private->dirname = g_path_get_dirname( info->private->filename );
+	info->private->basename = g_path_get_basename( info->private->filename );
 	info->private->hostname = g_strdup( vfs->host_name );
 	info->private->username = g_strdup( vfs->user_name );
 	info->private->scheme = g_strdup( vfs->scheme );
@@ -724,19 +817,15 @@ new_from_uri( const gchar *uri, const gchar *mimetype, gchar **errmsg )
 	na_gnome_vfs_uri_free( vfs );
 
 	location = g_file_new_for_uri( uri );
-	if( query_file_attributes( info, location, errmsg )){
-		dump( info );
-
-	} else {
-		g_object_unref( info );
-		info = NULL;
-	}
+	query_file_attributes( info, location, errmsg );
 	g_object_unref( location );
 
+	dump( info );
+
 	return( info );
 }
 
-static gboolean
+static void
 query_file_attributes( NASelectedInfo *nsi, GFile *location, gchar **errmsg )
 {
 	static const gchar *thisfn = "na_selected_info_query_file_attributes";
@@ -756,10 +845,11 @@ query_file_attributes( NASelectedInfo *nsi, GFile *location, gchar **errmsg )
 		if( errmsg ){
 			*errmsg = g_strdup_printf( _( "Error when querying informations for %s URI: %s" ), nsi->private->uri, error->message );
 		} else {
+			g_warning( "%s: URI='%s'", thisfn, nsi->private->uri );
 			g_warning( "%s: g_file_query_info: %s", thisfn, error->message );
 		}
 		g_error_free( error );
-		return( FALSE );
+		return;
 	}
 
 	if( !nsi->private->mimetype ){
@@ -774,7 +864,7 @@ query_file_attributes( NASelectedInfo *nsi, GFile *location, gchar **errmsg )
 
 	nsi->private->owner = g_strdup( g_file_info_get_attribute_as_string( info, G_FILE_ATTRIBUTE_OWNER_USER ));
 
-	g_object_unref( info );
+	nsi->private->attributes_are_set = TRUE;
 
-	return( TRUE );
+	g_object_unref( info );
 }
