@@ -32,7 +32,9 @@
 #include <config.h>
 #endif
 
+#include <gio/gunixinputstream.h>
 #include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 #include <api/na-core-utils.h>
@@ -40,6 +42,7 @@
 
 #include "na-gnome-vfs-uri.h"
 #include "na-selected-info.h"
+#include "na-settings.h"
 #include "na-tokens.h"
 
 /* private class data
@@ -52,30 +55,30 @@ struct _NATokensClassPrivate {
  */
 struct _NATokensPrivate {
 	gboolean dispose_has_run;
-
 	guint    count;
-
 	GSList  *uris;
-	gchar   *uris_str;
 	GSList  *filenames;
-	gchar   *filenames_str;
 	GSList  *basedirs;
-	gchar   *basedirs_str;
 	GSList  *basenames;
-	gchar   *basenames_str;
 	GSList  *basenames_woext;
-	gchar   *basenames_woext_str;
 	GSList  *exts;
-	gchar   *exts_str;
 	GSList  *mimetypes;
-	gchar   *mimetypes_str;
-
 	gchar   *hostname;
 	gchar   *username;
 	guint    port;
 	gchar   *scheme;
 };
 
+/*  the structure passed to the callback which waits for the end of the child
+ */
+typedef struct {
+	gchar   *command;
+	gboolean is_output_displayed;
+	gint     child_stdout;
+	gint     child_stderr;
+}
+	ChildStr;
+
 static GObjectClass *st_parent_class = NULL;
 
 static GType     register_type( void );
@@ -84,11 +87,18 @@ static void      instance_init( GTypeInstance *instance, gpointer klass );
 static void      instance_dispose( GObject *object );
 static void      instance_finalize( GObject *object );
 
-static NATokens *build_string_lists( NATokens *tokens );
-static gchar    *build_string_lists_item( GSList **pslist );
-static void      execute_action_command( const gchar *command, const NAObjectProfile *profile );
+static void      child_watch_fn( GPid pid, gint status, ChildStr *child_str );
+static void      display_output( const gchar *command, int fd_stdout, int fd_stderr );
+static gchar    *display_output_get_content( int fd );
+static void      execute_action_command( gchar *command, const NAObjectProfile *profile );
+static gchar    *get_command_execution_display_output( const gchar *command );
+static gchar    *get_command_execution_embedded( const gchar *command );
+static gchar    *get_command_execution_normal( const gchar *command );
+static gchar    *get_command_execution_terminal( const gchar *command );
 static gboolean  is_singular_exec( const NATokens *tokens, const gchar *exec );
-static gchar    *parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean utf8 );
+static gchar    *parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean utf8, gboolean quoted );
+static GString  *quote_string( GString *input, const gchar *name, gboolean quoted );
+static GString  *quote_string_list( GString *input, GSList *names, gboolean quoted );
 
 GType
 na_tokens_get_type( void )
@@ -151,28 +161,21 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	NATokens *self;
 
 	g_return_if_fail( NA_IS_TOKENS( instance ));
-	self = NA_TOKENS( instance );
 
 	g_debug( "%s: instance=%p (%s), klass=%p",
 			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 
+	self = NA_TOKENS( instance );
+
 	self->private = g_new0( NATokensPrivate, 1 );
 
 	self->private->uris = NULL;
-	self->private->uris_str = NULL;
 	self->private->filenames = NULL;
-	self->private->filenames_str = NULL;
 	self->private->basedirs = NULL;
-	self->private->basedirs_str = NULL;
 	self->private->basenames = NULL;
-	self->private->basenames_str = NULL;
 	self->private->basenames_woext = NULL;
-	self->private->basenames_woext_str = NULL;
 	self->private->exts = NULL;
-	self->private->exts_str = NULL;
 	self->private->mimetypes = NULL;
-	self->private->mimetypes_str = NULL;
-
 	self->private->hostname = NULL;
 	self->private->username = NULL;
 	self->private->port = 0;
@@ -188,6 +191,7 @@ instance_dispose( GObject *object )
 	NATokens *self;
 
 	g_return_if_fail( NA_IS_TOKENS( object ));
+
 	self = NA_TOKENS( object );
 
 	if( !self->private->dispose_has_run ){
@@ -209,27 +213,20 @@ instance_finalize( GObject *object )
 	NATokens *self;
 
 	g_return_if_fail( NA_IS_TOKENS( object ));
-	self = NA_TOKENS( object );
 
-	g_debug( "%s: object=%p", thisfn, ( void * ) object );
+	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
+	self = NA_TOKENS( object );
 
 	g_free( self->private->scheme );
 	g_free( self->private->username );
 	g_free( self->private->hostname );
-
-	g_free( self->private->mimetypes_str );
 	na_core_utils_slist_free( self->private->mimetypes );
-	g_free( self->private->exts_str );
 	na_core_utils_slist_free( self->private->exts );
-	g_free( self->private->basenames_woext_str );
 	na_core_utils_slist_free( self->private->basenames_woext );
-	g_free( self->private->basenames_str );
 	na_core_utils_slist_free( self->private->basenames );
-	g_free( self->private->basedirs_str );
 	na_core_utils_slist_free( self->private->basedirs );
-	g_free( self->private->filenames_str );
 	na_core_utils_slist_free( self->private->filenames );
-	g_free( self->private->uris_str );
 	na_core_utils_slist_free( self->private->uris );
 
 	g_free( self->private );
@@ -298,7 +295,7 @@ na_tokens_new_for_example( void )
 	tokens->private->username = g_strdup( ex_user );
 	tokens->private->port = ex_port;
 
-	return( build_string_lists( tokens ));
+	return( tokens );
 }
 
 /*
@@ -340,41 +337,36 @@ na_tokens_new_from_selection( GList *selection )
 			first = FALSE;
 		}
 
-		tokens->private->uris = g_slist_prepend( tokens->private->uris, uri );
-
-		tokens->private->filenames = g_slist_prepend( tokens->private->filenames, g_shell_quote( filename ));
-		tokens->private->basedirs = g_slist_prepend( tokens->private->basedirs, g_shell_quote( basedir ));
-		tokens->private->basenames = g_slist_prepend( tokens->private->basenames, g_shell_quote( basename ));
-		tokens->private->basenames_woext = g_slist_prepend( tokens->private->basenames_woext, g_shell_quote( bname_woext ));
-		tokens->private->exts = g_slist_prepend( tokens->private->exts, g_shell_quote( ext ));
-
-		g_free( filename );
-		g_free( basedir );
-		g_free( basename );
-		g_free( bname_woext );
-		g_free( ext );
-
-		tokens->private->mimetypes = g_slist_prepend( tokens->private->mimetypes, mimetype );
+		tokens->private->uris = g_slist_append( tokens->private->uris, uri );
+		tokens->private->filenames = g_slist_append( tokens->private->filenames, filename );
+		tokens->private->basedirs = g_slist_append( tokens->private->basedirs, basedir );
+		tokens->private->basenames = g_slist_append( tokens->private->basenames, basename );
+		tokens->private->basenames_woext = g_slist_append( tokens->private->basenames_woext, bname_woext );
+		tokens->private->exts = g_slist_append( tokens->private->exts, ext );
+		tokens->private->mimetypes = g_slist_append( tokens->private->mimetypes, mimetype );
 	}
 
-	return( build_string_lists( tokens ));
+	return( tokens );
 }
 
 /*
- * na_tokens_parse_parameters:
+ * na_tokens_parse_for_display:
  * @tokens: a #NATokens object.
  * @string: the input string, may or may not contain tokens.
  * @utf8: whether the @input string is UTF-8 encoded, or a standard ASCII string.
  *
  * Expands the parameters in the given string.
  *
+ * This expanded string is meant to be displayed only (not executed) as
+ * filenames are not shell-quoted.
+ *
  * Returns: a copy of @input string with tokens expanded, as a newly
  * allocated string which should be g_free() by the caller.
  */
 gchar *
-na_tokens_parse_parameters( const NATokens *tokens, const gchar *string, gboolean utf8 )
+na_tokens_parse_for_display( const NATokens *tokens, const gchar *string, gboolean utf8 )
 {
-	return( parse_singular( tokens, string, 0, utf8 ));
+	return( parse_singular( tokens, string, 0, utf8, FALSE ));
 }
 
 /*
@@ -387,9 +379,10 @@ na_tokens_parse_parameters( const NATokens *tokens, const gchar *string, gboolea
 void
 na_tokens_execute_action( const NATokens *tokens, const NAObjectProfile *profile )
 {
-	gchar *path, *parameters, *exec, *command;
+	gchar *path, *parameters, *exec;
 	gboolean singular;
 	guint i;
+	gchar *command;
 
 	path = na_object_get_path( profile );
 	parameters = na_object_get_parameters( profile );
@@ -401,53 +394,260 @@ na_tokens_execute_action( const NATokens *tokens, const NAObjectProfile *profile
 
 	if( singular ){
 		for( i = 0 ; i < tokens->private->count ; ++i ){
-			command = parse_singular( tokens, exec, i, FALSE );
+			command = parse_singular( tokens, exec, i, FALSE, TRUE );
 			execute_action_command( command, profile );
 			g_free( command );
 		}
 
 	} else {
-		command = na_tokens_parse_parameters( tokens, exec, FALSE );
+		command = parse_singular( tokens, exec, 0, FALSE, TRUE );
 		execute_action_command( command, profile );
 		g_free( command );
 	}
 
-
 	g_free( exec );
 }
 
-static NATokens *
-build_string_lists( NATokens *tokens )
+static void
+child_watch_fn( GPid pid, gint status, ChildStr *child_str )
 {
-	tokens->private->uris_str            = build_string_lists_item( &tokens->private->uris );
-	tokens->private->filenames_str       = build_string_lists_item( &tokens->private->filenames );
-	tokens->private->basedirs_str        = build_string_lists_item( &tokens->private->basedirs );
-	tokens->private->basenames_str       = build_string_lists_item( &tokens->private->basenames );
-	tokens->private->basenames_woext_str = build_string_lists_item( &tokens->private->basenames_woext );
-	tokens->private->exts_str            = build_string_lists_item( &tokens->private->exts );
-	tokens->private->mimetypes_str       = build_string_lists_item( &tokens->private->mimetypes );
+	static const gchar *thisfn = "na_tokens_child_watch_fn";
 
-	return( tokens );
-}
-
-static gchar *
-build_string_lists_item( GSList **pslist )
-{
-	*pslist = g_slist_reverse( *pslist );
-
-	gchar *str = na_core_utils_slist_join_at_end( *pslist, " " );
-
-	return( str );
+	g_debug( "%s: pid=%u, status=%d", thisfn, ( guint ) pid, status );
+	g_spawn_close_pid( pid );
+	if( child_str->is_output_displayed ){
+		display_output( child_str->command, child_str->child_stdout, child_str->child_stderr );
+	}
+	g_free( child_str->command );
+	g_free( child_str );
 }
 
 static void
-execute_action_command( const gchar *command, const NAObjectProfile *profile )
+display_output( const gchar *command, int fd_stdout, int fd_stderr )
+{
+	GtkWidget *dialog;
+	gchar *std_output, *std_error;
+
+	dialog = gtk_message_dialog_new_with_markup(
+			NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_OK, "<b>%s</b>", _( "Output of the run command" ));
+	g_object_set( G_OBJECT( dialog ) , "title", PACKAGE_NAME, NULL );
+
+	std_output = display_output_get_content( fd_stdout );
+	std_error = display_output_get_content( fd_stderr );
+
+	gtk_message_dialog_format_secondary_markup( GTK_MESSAGE_DIALOG( dialog ),
+			"<b>%s</b>\n%s\n\n<b>%s</b>\n%s\n\n<b>%s</b>\n%s\n\n",
+					_( "Run command:" ), command,
+					_( "Standard output:" ), std_output,
+					_( "Standard error:" ), std_error );
+
+	gtk_dialog_run( GTK_DIALOG( dialog ));
+	gtk_widget_destroy( dialog );
+
+	g_free( std_output );
+	g_free( std_error );
+}
+
+static gchar *
+display_output_get_content( int fd )
+{
+	static const gchar *thisfn = "na_tokens_display_output_get_content";
+	GInputStream *stream;
+	GString *string;
+	gchar buf[1024];
+	GError *error;
+	gchar *msg;
+
+	string = g_string_new( "" );
+	memset( buf, '\0', sizeof( buf ));
+
+	if( fd > 0 ){
+		stream = g_unix_input_stream_new( fd, TRUE );
+		error = NULL;
+
+		while( g_input_stream_read( stream, buf, sizeof( buf )-1, NULL, &error )){
+			string = g_string_append( string, buf );
+			memset( buf, '\0', sizeof( buf ));
+		}
+		if( error ){
+			g_warning( "%s: g_input_stream_read: %s", thisfn, error->message );
+			g_error_free( error );
+		}
+		g_input_stream_close( stream, NULL, NULL );
+	}
+
+	msg = g_locale_to_utf8( string->str, -1, NULL, NULL, NULL );
+	g_string_free( string, TRUE );
+
+	return( msg );
+}
+
+/*
+ * Execution environment:
+ * - Normal: just execute the specified command
+ * - Terminal: use the user preference to have a terminal which stays openeded
+ * - Embedded: id. Terminal
+ * - DisplayOutput: execute in a shell
+ */
+static void
+execute_action_command( gchar *command, const NAObjectProfile *profile )
 {
 	static const gchar *thisfn = "nautilus_actions_execute_action_command";
+	GError *error;
+	gchar *execution_mode, *run_command;
+	gchar **argv;
+	gint argc;
+	gchar *wdir;
+	GPid child_pid;
+	ChildStr *child_str;
 
-	g_debug( "%s: command=%s, profile=%p", thisfn, command, ( void * ) profile );
+	g_debug( "%s: profile=%p", thisfn, ( void * ) profile );
 
-	g_spawn_command_line_async( command, NULL );
+	error = NULL;
+	run_command = NULL;
+	child_str = g_new0( ChildStr, 1 );
+	child_pid = ( GPid ) 0;
+	execution_mode = na_object_get_execution_mode( profile );
+
+	if( !strcmp( execution_mode, "Normal" )){
+		run_command = get_command_execution_normal( command );
+
+	} else if( !strcmp( execution_mode, "Terminal" )){
+		run_command = get_command_execution_terminal( command );
+
+	} else if( !strcmp( execution_mode, "Embedded" )){
+		run_command = get_command_execution_embedded( command );
+
+	} else if( !strcmp( execution_mode, "DisplayOutput" )){
+		child_str->is_output_displayed = TRUE;
+		run_command = get_command_execution_display_output( command );
+
+	} else {
+		g_warning( "%s: unknown execution mode: %s", thisfn, execution_mode );
+	}
+
+	if( run_command ){
+		child_str->command = g_strdup( run_command );
+
+		if( !g_shell_parse_argv( run_command, &argc, &argv, &error )){
+			g_warning( "%s: g_shell_parse_argv: %s", thisfn, error->message );
+			g_error_free( error );
+
+		} else {
+			wdir = na_object_get_working_dir( profile );
+			g_debug( "%s: run_command=%s, wdir=%s", thisfn, run_command, wdir );
+
+			/* it appears that at least mplayer does not support g_spawn_async_with_pipes
+			 * (at least when notrun in '-quiet' mode) while, e.g., totem and vlc rightly
+			 * support this function
+			 * So only use g_spawn_async_with_pipes when we really need to get back
+			 * the content of output and error streams
+			 * See https://bugzilla.gnome.org/show_bug.cgi?id=644289.
+			 */
+			if( child_str->is_output_displayed ){
+				g_spawn_async_with_pipes( wdir,
+						argv,
+						NULL,
+						G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
+						NULL,
+						NULL,
+						&child_pid,
+						NULL,
+						&child_str->child_stdout,
+						&child_str->child_stderr,
+						&error );
+
+			} else {
+				g_spawn_async( wdir,
+						argv,
+						NULL,
+						G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
+						NULL,
+						NULL,
+						&child_pid,
+						&error );
+			}
+
+			if( error ){
+				g_warning( "%s: g_spawn_async: %s", thisfn, error->message );
+				g_error_free( error );
+				child_pid = ( GPid ) 0;
+
+			} else {
+				g_child_watch_add( child_pid, ( GChildWatchFunc ) child_watch_fn, child_str );
+			}
+
+			g_free( wdir );
+			g_strfreev( argv );
+		}
+
+		g_free( run_command );
+	}
+
+	g_free( execution_mode );
+
+	if( child_pid == ( GPid ) 0 ){
+		g_free( child_str->command );
+		g_free( child_str );
+	}
+}
+
+static gchar *
+get_command_execution_display_output( const gchar *command )
+{
+	static const gchar *bin_sh = "/bin/sh -c COMMAND";
+	return( na_tokens_command_for_terminal( bin_sh, command ));
+}
+
+static gchar *
+get_command_execution_embedded( const gchar *command )
+{
+	return( get_command_execution_terminal( command ));
+}
+
+static gchar *
+get_command_execution_normal( const gchar *command )
+{
+	return( g_strdup( command ));
+}
+
+static gchar *
+get_command_execution_terminal( const gchar *command )
+{
+	gchar *run_command;
+	gchar *pattern;
+
+	pattern = na_settings_get_string( NA_IPREFS_TERMINAL_PATTERN, NULL, NULL );
+	run_command = na_tokens_command_for_terminal( pattern, command );
+	g_free( pattern );
+
+	return( run_command );
+}
+
+/**
+ * na_tokens_command_for_terminal:
+ * @pattern: the command pattern; should include a 'COMMAND' keyword
+ * @command: the command to be actually run in the terminal
+ *
+ * Returns: the command to be run, as a newly allocated string which should
+ * be g_free() by the caller.
+ */
+gchar *
+na_tokens_command_for_terminal( const gchar *pattern, const gchar *command )
+{
+	gchar *run_command;
+	gchar *quoted;
+
+	if( pattern && strlen( pattern )){
+		quoted = g_shell_quote( command );
+		run_command = na_core_utils_str_subst( pattern, "COMMAND", quoted );
+		g_free( quoted );
+
+	} else {
+		run_command = g_strdup( command );
+	}
+
+	return( run_command );
 }
 
 /*
@@ -513,7 +713,7 @@ is_singular_exec( const NATokens *tokens, const gchar *exec )
 }
 
 /*
- * na_tokens_parse_singular:
+ * parse_singular:
  * @tokens: a #NATokens object.
  * @input: the input string, may or may not contain tokens.
  * @i: the number of the iteration in a multiple selection, starting with zero.
@@ -523,12 +723,15 @@ is_singular_exec( const NATokens *tokens, const gchar *exec )
  * A command is said of 'singular form' when its first parameter is not
  * of plural form. In the case of a multiple selection, singular form
  * commands are executed one time for each element of the selection
+ *
+ * Returns: a #GSList which contains two fields: the command and its parameters.
+ * The returned #GSList should be na_core_utils_slist_free() by the caller.
  */
 static gchar *
-parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean utf8 )
+parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean utf8, gboolean quoted )
 {
 	GString *output;
-	gchar *iter, *prev_iter, *tmp;
+	gchar *iter, *prev_iter;
 	const gchar *nth;
 
 	output = g_string_new( "" );
@@ -562,14 +765,14 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 				if( tokens->private->basenames ){
 					nth = ( const gchar * ) g_slist_nth_data( tokens->private->basenames, i );
 					if( nth ){
-						output = g_string_append( output, nth );
+						output = quote_string( output, nth, quoted );
 					}
 				}
 				break;
 
 			case 'B':
-				if( tokens->private->basenames_str ){
-					output = g_string_append( output, tokens->private->basenames_str );
+				if( tokens->private->basenames ){
+					output = quote_string_list( output, tokens->private->basenames, quoted );
 				}
 				break;
 
@@ -581,14 +784,14 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 				if( tokens->private->basedirs ){
 					nth = ( const gchar * ) g_slist_nth_data( tokens->private->basedirs, i );
 					if( nth ){
-						output = g_string_append( output, nth );
+						output = quote_string( output, nth, quoted );
 					}
 				}
 				break;
 
 			case 'D':
-				if( tokens->private->basedirs_str ){
-					output = g_string_append( output, tokens->private->basedirs_str );
+				if( tokens->private->basedirs ){
+					output = quote_string_list( output, tokens->private->basedirs, quoted );
 				}
 				break;
 
@@ -596,39 +799,37 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 				if( tokens->private->filenames ){
 					nth = ( const gchar * ) g_slist_nth_data( tokens->private->filenames, i );
 					if( nth ){
-						output = g_string_append( output, nth );
+						output = quote_string( output, nth, quoted );
 					}
 				}
 				break;
 
 			case 'F':
-				if( tokens->private->filenames_str ){
-					output = g_string_append( output, tokens->private->filenames_str );
+				if( tokens->private->filenames ){
+					output = quote_string_list( output, tokens->private->filenames, quoted );
 				}
 				break;
 
 			case 'h':
 				if( tokens->private->hostname ){
-					tmp = g_shell_quote( tokens->private->hostname );
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					output = quote_string( output, tokens->private->hostname, quoted );
 				}
 				break;
 
+			/* mimetypes are never quoted
+			 */
 			case 'm':
 				if( tokens->private->mimetypes ){
 					nth = ( const gchar * ) g_slist_nth_data( tokens->private->mimetypes, i );
 					if( nth ){
-						tmp = g_shell_quote( nth );
-						output = g_string_append( output, tmp );
-						g_free( tmp );
+						output = quote_string( output, nth, FALSE );
 					}
 				}
 				break;
 
 			case 'M':
-				if( tokens->private->mimetypes_str ){
-					output = g_string_append( output, tokens->private->mimetypes_str );
+				if( tokens->private->mimetypes ){
+					output = quote_string_list( output, tokens->private->mimetypes, FALSE );
 				}
 				break;
 
@@ -639,21 +840,21 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 
 			case 'n':
 				if( tokens->private->username ){
-					tmp = g_shell_quote( tokens->private->username );
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					output = quote_string( output, tokens->private->username, quoted );
 				}
 				break;
 
+			/* port number is never quoted
+			 */
 			case 'p':
-				g_string_append_printf( output, "%d", tokens->private->port );
+				if( tokens->private->port > 0 ){
+					g_string_append_printf( output, "%d", tokens->private->port );
+				}
 				break;
 
 			case 's':
 				if( tokens->private->scheme ){
-					tmp = g_shell_quote( tokens->private->scheme );
-					output = g_string_append( output, tmp );
-					g_free( tmp );
+					output = quote_string( output, tokens->private->scheme, quoted );
 				}
 				break;
 
@@ -661,16 +862,14 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 				if( tokens->private->uris ){
 					nth = ( const gchar * ) g_slist_nth_data( tokens->private->uris, i );
 					if( nth ){
-						tmp = g_shell_quote( nth );
-						output = g_string_append( output, tmp );
-						g_free( tmp );
+						output = quote_string( output, nth, quoted );
 					}
 				}
 				break;
 
 			case 'U':
-				if( tokens->private->uris_str ){
-					output = g_string_append( output, tokens->private->uris_str );
+				if( tokens->private->uris ){
+					output = quote_string_list( output, tokens->private->uris, quoted );
 				}
 				break;
 
@@ -678,14 +877,14 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 				if( tokens->private->basenames_woext ){
 					nth = ( const gchar * ) g_slist_nth_data( tokens->private->basenames_woext, i );
 					if( nth ){
-						output = g_string_append( output, nth );
+						output = quote_string( output, nth, quoted );
 					}
 				}
 				break;
 
 			case 'W':
-				if( tokens->private->basenames_woext_str ){
-					output = g_string_append( output, tokens->private->basenames_woext_str );
+				if( tokens->private->basenames_woext ){
+					output = quote_string_list( output, tokens->private->basenames_woext, quoted );
 				}
 				break;
 
@@ -693,14 +892,14 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 				if( tokens->private->exts ){
 					nth = ( const gchar * ) g_slist_nth_data( tokens->private->exts, i );
 					if( nth ){
-						output = g_string_append( output, nth );
+						output = quote_string( output, nth, quoted );
 					}
 				}
 				break;
 
 			case 'X':
-				if( tokens->private->exts_str ){
-					output = g_string_append( output, tokens->private->exts_str );
+				if( tokens->private->exts ){
+					output = quote_string_list( output, tokens->private->exts, quoted );
 				}
 				break;
 
@@ -719,3 +918,44 @@ parse_singular( const NATokens *tokens, const gchar *input, guint i, gboolean ut
 
 	return( g_string_free( output, FALSE ));
 }
+
+static GString *
+quote_string( GString *input, const gchar *name, gboolean quoted )
+{
+	gchar *tmp;
+
+	if( quoted ){
+		tmp = g_shell_quote( name );
+		input = g_string_append( input, tmp );
+		g_free( tmp );
+
+	} else {
+		input = g_string_append( input, name );
+	}
+
+	return( input );
+}
+
+static GString *
+quote_string_list( GString *input, GSList *names, gboolean quoted )
+{
+	GSList *it;
+	gchar *tmp;
+
+	if( quoted ){
+		GSList *quoted_names = NULL;
+		for( it = names ; it ; it = it->next ){
+			quoted_names = g_slist_append( quoted_names, g_shell_quote(( const gchar * ) it->data ));
+		}
+		tmp = na_core_utils_slist_join_at_end( quoted_names, " " );
+		na_core_utils_slist_free( quoted_names );
+
+	} else {
+		tmp = na_core_utils_slist_join_at_end( g_slist_reverse( names ), " " );
+	}
+
+	input = g_string_append( input, tmp );
+	g_free( tmp );
+
+	return( input );
+}
