@@ -483,7 +483,7 @@ read_start_profile_attach_profile( const NAIFactoryProvider *provider, NAObjectP
 NADataBoxed *
 nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void *reader_data, const NAIFactoryObject *object, const NADataDef *def, GSList **messages )
 {
-	static const gchar *thisfn = "nadp_reader_ifactory_provider_read_value";
+	static const gchar *thisfn = "nadp_reader_ifactory_provider_read_data";
 	NADataBoxed *boxed;
 	gboolean found;
 	NadpReaderData *nrd;
@@ -494,13 +494,6 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
 	GSList *slist_value;
 	guint uint_value;
 
-	/*g_debug( "%s: reader=%p (%s), reader_data=%p, def=%p (%s), messages=%p",
-			thisfn,
-			( void * ) reader, G_OBJECT_TYPE_NAME( reader ),
-			( void * ) reader_data,
-			( void * ) def, def->name,
-			( void * ) messages );*/
-
 	g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( reader ), NULL );
 	g_return_val_if_fail( NADP_IS_DESKTOP_PROVIDER( reader ), NULL );
 	g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), NULL );
@@ -526,47 +519,46 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
 
 			switch( def->type ){
 
-				case NAFD_TYPE_LOCALE_STRING:
+				case NA_DATA_TYPE_LOCALE_STRING:
 					str_value = nadp_desktop_file_get_locale_string( nrd->ndf, group, def->desktop_entry, &found, def->default_value );
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, str_value );
+						na_boxed_set_from_void( NA_BOXED( boxed ), str_value );
 					}
 					g_free( str_value );
 					break;
 
-				case NAFD_TYPE_STRING:
+				case NA_DATA_TYPE_STRING:
 					str_value = nadp_desktop_file_get_string( nrd->ndf, group, def->desktop_entry, &found, def->default_value );
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, str_value );
+						na_boxed_set_from_void( NA_BOXED( boxed ), str_value );
 					}
 					g_free( str_value );
 					break;
 
-				case NAFD_TYPE_BOOLEAN:
+				case NA_DATA_TYPE_BOOLEAN:
 					bool_value = nadp_desktop_file_get_boolean( nrd->ndf, group, def->desktop_entry, &found, na_core_utils_boolean_from_string( def->default_value ));
-					g_debug( "%s: name=%s, found=%s, value=%s", thisfn, def->name, found ? "True":"False", bool_value ? "True":"False" );
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, GUINT_TO_POINTER( bool_value ));
+						na_boxed_set_from_void( NA_BOXED( boxed ), GUINT_TO_POINTER( bool_value ));
 					}
 					break;
 
-				case NAFD_TYPE_STRING_LIST:
+				case NA_DATA_TYPE_STRING_LIST:
 					slist_value = nadp_desktop_file_get_string_list( nrd->ndf, group, def->desktop_entry, &found, def->default_value );
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, slist_value );
+						na_boxed_set_from_void( NA_BOXED( boxed ), slist_value );
 					}
 					na_core_utils_slist_free( slist_value );
 					break;
 
-				case NAFD_TYPE_UINT:
+				case NA_DATA_TYPE_UINT:
 					uint_value = nadp_desktop_file_get_uint( nrd->ndf, group, def->desktop_entry, &found, atoi( def->default_value ));
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, GUINT_TO_POINTER( uint_value ));
+						na_boxed_set_from_void( NA_BOXED( boxed ), GUINT_TO_POINTER( uint_value ));
 					}
 					break;
 
@@ -584,7 +576,7 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
 }
 
 /*
- * called when each NAIFactoryObject object has been readen
+ * called when each NAIFactoryObject object has been read
  */
 void
 nadp_reader_ifactory_provider_read_done( const NAIFactoryProvider *reader, void *reader_data, const NAIFactoryObject *serializable, GSList **messages )
