@@ -49,7 +49,7 @@
 
 /* private class data
  */
-struct NAXMLReaderClassPrivate {
+struct _NAXMLReaderClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
@@ -73,7 +73,7 @@ typedef struct {
  * main naxml_reader_import_from_uri() function is called once for each file
  * to import. We thus have one NAXMLReader object per import operation.
  */
-struct NAXMLReaderPrivate {
+struct _NAXMLReaderPrivate {
 	gboolean                       dispose_has_run;
 
 	/* data provided by the caller
@@ -169,6 +169,7 @@ static guint         reader_parse_xmldoc( NAXMLReader *reader );
 static guint         iter_on_root_children( NAXMLReader *reader, xmlNode *root );
 static guint         iter_on_list_children( NAXMLReader *reader, xmlNode *first );
 
+static gchar        *slist_to_string( GSList *slist );
 static gchar        *build_key_node_list( NAXMLKeyStr *strlist );
 static gchar        *build_root_node_list( void );
 static gchar        *get_value_from_child_node( xmlNode *node, const gchar *child );
@@ -338,7 +339,7 @@ naxml_reader_import_from_uri( const NAIImporter *instance, NAIImporterImportFrom
 	code = reader_parse_xmldoc( reader );
 
 	if( code == IMPORTER_CODE_OK ){
-		g_assert( NA_IS_OBJECT_ITEM( reader->private->parms->imported ));
+		g_return_val_if_fail( NA_IS_OBJECT_ITEM( reader->private->parms->imported ), IMPORTER_CODE_PROGRAM_ERROR );
 		code = manage_import_mode( reader );
 	}
 
@@ -474,8 +475,8 @@ iter_on_root_children( NAXMLReader *reader, xmlNode *root )
  * this first pass is also used to check nodes
  *
  * - for each node, check that
- *   > 'schema/entry' childs are in the list of known schema/entry child nodes
- *   > 'schema/entry' childs appear only once per node
+ *   > 'schema/entry' children are in the list of known schema/entry child nodes
+ *   > 'schema/entry' children appear only once per node
  *     -> this requires a per-node 'found' flag which is reset for each node
  *   > schema has an 'applyto' child node
  *     -> only checkable at the end of the schema
@@ -608,7 +609,7 @@ read_start_profile_attach_profile( NAXMLReader *reader, NAObjectProfile *profile
  * this callback function is called by NAIFactoryObject once for each
  * serializable data for the object
  *
- * Note that some nodes may be readen twice because of multiple definition
+ * Note that some nodes may be read twice because of multiple definition
  * of the same data (e.g. icon which exists in localized and unlocalized
  * versions). So do not remove dealt-with nodes here
  */
@@ -726,7 +727,7 @@ read_data_boxed_from_node( NAXMLReader *reader, xmlChar *path, xmlNode *parent,
 		if( reader->private->root_node_str->fn_get_value ){
 			value = ( *reader->private->root_node_str->fn_get_value )( reader, parent, def );
 			boxed = na_data_boxed_new( def );
-			na_data_boxed_set_from_string( boxed, value );
+			na_boxed_set_from_string( NA_BOXED( boxed ), value );
 			g_free( value );
 		}
 	}
@@ -737,7 +738,7 @@ read_data_boxed_from_node( NAXMLReader *reader, xmlChar *path, xmlNode *parent,
 }
 
 /*
- * all serializable data of the object has been readen
+ * all serializable data of the object has been read
  */
 void
 naxml_reader_read_done( const NAIFactoryProvider *provider, void *reader_data, const NAIFactoryObject *object, GSList **messages  )
@@ -770,7 +771,7 @@ naxml_reader_read_done( const NAIFactoryProvider *provider, void *reader_data, c
 }
 
 /*
- * just having readen this NAObjectItem
+ * just having read this NAObjectItem
  * so deals with unlocalized/localized icon name/path
  */
 static void
@@ -890,7 +891,7 @@ read_done_action_load_profile( NAXMLReader *reader, const gchar *profile_id )
 }
 
 /*
- * just having readen this NAObjectProfile
+ * just having read this NAObjectProfile
  * so deals with unlocalized/localized desc-name
  */
 static void
@@ -1198,14 +1199,14 @@ dump_read_value( NAXMLReader *reader, xmlNode *node, const NADataDef *def )
 	string = NULL;
 
 	switch( def->type ){
-		case NAFD_TYPE_STRING:
-		case NAFD_TYPE_LOCALE_STRING:
-		case NAFD_TYPE_UINT:
-		case NAFD_TYPE_BOOLEAN:
+		case NA_DATA_TYPE_STRING:
+		case NA_DATA_TYPE_LOCALE_STRING:
+		case NA_DATA_TYPE_UINT:
+		case NA_DATA_TYPE_BOOLEAN:
 			string = get_value_from_child_child_node( node, NAXML_KEY_DUMP_NODE_VALUE, NAXML_KEY_DUMP_NODE_VALUE_TYPE_STRING );
 			break;
 
-		case NAFD_TYPE_STRING_LIST:
+		case NA_DATA_TYPE_STRING_LIST:
 			slist = NULL;
 			value_node = search_for_child_node( node, NAXML_KEY_DUMP_NODE_VALUE );
 
@@ -1227,11 +1228,11 @@ dump_read_value( NAXMLReader *reader, xmlNode *node, const NADataDef *def )
 					}
 				}
 			}
-			string = na_gconf_utils_slist_to_string( slist );
+			string = slist_to_string( slist );
 			na_core_utils_slist_free( slist );
 			break;
 
-		case NAFD_TYPE_POINTER:
+		case NA_DATA_TYPE_POINTER:
 		default:
 			break;
 	}
@@ -1239,6 +1240,27 @@ dump_read_value( NAXMLReader *reader, xmlNode *node, const NADataDef *def )
 	return( string );
 }
 
+static gchar *
+slist_to_string( GSList *slist )
+{
+	GSList *is;
+	GString *str = g_string_new( "[" );
+	gboolean first;
+
+	first = TRUE;
+	for( is = slist ; is ; is = is->next ){
+		if( !first ){
+			str = g_string_append( str, "," );
+		}
+		str = g_string_append( str, ( const gchar * ) is->data );
+		first = FALSE;
+	}
+
+	str = g_string_append( str, "]" );
+
+	return( g_string_free( str, FALSE ));
+}
+
 static gchar *
 build_key_node_list( NAXMLKeyStr *strlist )
 {
@@ -1377,7 +1399,9 @@ publish_undealt_nodes( NAXMLReader *reader )
 
 		if( !g_list_find( reader->private->dealt, node )){
 			text = xmlNodeGetContent( node );
-			na_core_utils_slist_add_message( &reader->private->parms->messages, WARN_UNDEALT_NODE, ( const gchar * ) text, node->line );
+			g_debug( "test=%s, line=%d", ( const gchar * ) text, node->line );
+			na_core_utils_slist_add_message(
+					&reader->private->parms->messages, WARN_UNDEALT_NODE, ( const gchar * ) text, node->line );
 			xmlFree( text );
 		}
 	}
