@@ -33,6 +33,7 @@
 #endif
 
 #include <gio/gio.h>
+#include <libintl.h>
 #include <libxml/tree.h>
 #include <string.h>
 
@@ -52,13 +53,13 @@ typedef struct ExportFormatFn ExportFormatFn;
 
 /* private class data
  */
-struct NAXMLWriterClassPrivate {
+struct _NAXMLWriterClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAXMLWriterPrivate {
+struct _NAXMLWriterPrivate {
 	gboolean         dispose_has_run;
 	NAIExporter     *provider;
 	NAObjectItem    *exported;
@@ -448,7 +449,7 @@ guint
 naxml_writer_write_data( const NAIFactoryProvider *provider, void *writer_data, const NAIFactoryObject *object, const NADataBoxed *boxed, GSList **messages )
 {
 	NAXMLWriter *writer;
-	NADataDef *def;
+	const NADataDef *def;
 
 	/*NADataDef *def = na_data_boxed_get_data_def( boxed );
 	g_debug( "naxml_writer_write_data: def=%s", def->name );*/
@@ -493,8 +494,8 @@ write_data_schema_v1_element( NAXMLWriter *writer, const NADataDef *def )
 	}
 
 	xmlNewChild( writer->private->schema_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_OWNER ), BAD_CAST( PACKAGE_TARNAME ));
-	xmlNewChild( writer->private->locale_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_LOCALE_SHORT ), BAD_CAST( def->short_label ));
-	xmlNewChild( writer->private->locale_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_LOCALE_LONG ), BAD_CAST( def->long_label ));
+	xmlNewChild( writer->private->locale_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_LOCALE_SHORT ), BAD_CAST( gettext( def->short_label )));
+	xmlNewChild( writer->private->locale_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_LOCALE_LONG ), BAD_CAST( gettext( def->long_label )));
 }
 
 static void
@@ -520,11 +521,11 @@ write_data_schema_v2( NAXMLWriter *writer, const NAObjectId *object, const NADat
 	gchar *object_id;
 	gchar *value_str;
 
-	value_str = na_data_boxed_get_as_string( boxed );
+	value_str = na_boxed_get_string( NA_BOXED( boxed ));
 
 	/* boolean value must be lowercase
 	 */
-	if( def->type == NAFD_TYPE_BOOLEAN ){
+	if( def->type == NA_DATA_TYPE_BOOLEAN ){
 		gchar *tmp = g_ascii_strdown( value_str, -1 );
 		g_free( value_str );
 		value_str = tmp;
@@ -569,7 +570,7 @@ write_data_schema_v2_element( NAXMLWriter *writer, const NADataDef *def, const g
 	xmlFree( content );
 
 	xmlNewChild( writer->private->schema_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_TYPE ), BAD_CAST( na_data_types_get_gconf_dump_key( def->type )));
-	if( def->type == NAFD_TYPE_STRING_LIST ){
+	if( def->type == NA_DATA_TYPE_STRING_LIST ){
 		xmlNewChild( writer->private->schema_node, NULL, BAD_CAST( NAXML_KEY_SCHEMA_NODE_LISTTYPE ), BAD_CAST( "string" ));
 	}
 
@@ -622,11 +623,11 @@ write_data_dump( NAXMLWriter *writer, const NAObjectId *object, const NADataBoxe
 	gchar *entry;
 	gchar *value_str;
 
-	value_str = na_data_boxed_get_as_string( boxed );
+	value_str = na_boxed_get_string( NA_BOXED( boxed ));
 
 	/* boolean value must be lowercase
 	 */
-	if( def->type == NAFD_TYPE_BOOLEAN ){
+	if( def->type == NA_DATA_TYPE_BOOLEAN ){
 		gchar *tmp = g_ascii_strdown( value_str, -1 );
 		g_free( value_str );
 		value_str = tmp;
@@ -661,11 +662,11 @@ write_data_dump_element( NAXMLWriter *writer, const NADataDef *def, const NAData
 
 	value_node = xmlNewChild( entry_node, NULL, BAD_CAST( NAXML_KEY_DUMP_NODE_VALUE ), NULL );
 
-	if( def->type == NAFD_TYPE_STRING_LIST ){
+	if( def->type == NA_DATA_TYPE_STRING_LIST ){
 		value_list_node = xmlNewChild( value_node, NULL, BAD_CAST( NAXML_KEY_DUMP_NODE_VALUE_LIST ), NULL );
 		xmlNewProp( value_list_node, BAD_CAST( NAXML_KEY_DUMP_NODE_VALUE_LIST_PARM_TYPE ), BAD_CAST( NAXML_KEY_DUMP_NODE_VALUE_TYPE_STRING ));
 		value_list_value_node = xmlNewChild( value_list_node, NULL, BAD_CAST( NAXML_KEY_DUMP_NODE_VALUE ), NULL );
-		list = ( GSList * ) na_data_boxed_get_as_void( boxed );
+		list = ( GSList * ) na_boxed_get_as_void( NA_BOXED( boxed ));
 
 		for( is = list ; is ; is = is->next ){
 			encoded_content = xmlEncodeSpecialChars( writer->private->doc, BAD_CAST(( gchar * ) is->data ));
@@ -673,6 +674,8 @@ write_data_dump_element( NAXMLWriter *writer, const NADataDef *def, const NAData
 			xmlFree( encoded_content );
 		}
 
+		na_core_utils_slist_free( list );
+
 	} else {
 		encoded_content = xmlEncodeSpecialChars( writer->private->doc, BAD_CAST( value_str ));
 		xmlNewChild( value_node, NULL, BAD_CAST( na_data_types_get_gconf_dump_key( def->type )), encoded_content );
