@@ -39,16 +39,16 @@
 
 #include <core/na-exporter.h>
 #include <core/na-export-format.h>
+#include <core/na-iprefs.h>
 
 #include "nact-application.h"
-#include "nact-iprefs.h"
 #include "nact-export-ask.h"
 #include "nact-tree-model.h"
 #include "nact-clipboard.h"
 
 /* private class data
  */
-struct NactClipboardClassPrivate {
+struct _NactClipboardClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
@@ -71,7 +71,7 @@ typedef struct {
 }
 	PrimaryData;
 
-struct NactClipboardPrivate {
+struct _NactClipboardPrivate {
 	gboolean      dispose_has_run;
 	BaseWindow   *window;
 	GtkClipboard *dnd;
@@ -115,7 +115,7 @@ static void   get_from_dnd_clipboard_callback( GtkClipboard *clipboard, GtkSelec
 static void   clear_dnd_clipboard_callback( GtkClipboard *clipboard, NactClipboardDndData *data );
 static gchar *export_rows( NactClipboard *clipboard, GList *rows, const gchar *dest_folder );
 static gchar *export_objects( NactClipboard *clipboard, GList *objects );
-static gchar *export_row_object( NactClipboard *clipboard, NAObject *object, const gchar *dest_folder, GList **exported );
+static gchar *export_row_object( NactClipboard *clipboard, NAObject *object, const gchar *dest_folder, GList **exported, gboolean first );
 
 static void   get_from_primary_clipboard_callback( GtkClipboard *gtk_clipboard, GtkSelectionData *selection_data, guint info, NactClipboard *clipboard );
 static void   clear_primary_clipboard( NactClipboard *clipboard );
@@ -185,9 +185,11 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	NactClipboard *self;
 	GdkDisplay *display;
 
+	g_return_if_fail( NACT_IS_CLIPBOARD( instance ));
+
 	g_debug( "%s: instance=%p (%s), klass=%p",
 			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-	g_assert( NACT_IS_CLIPBOARD( instance ));
+
 	self = NACT_CLIPBOARD( instance );
 
 	self->private = g_new0( NactClipboardPrivate, 1 );
@@ -206,12 +208,14 @@ instance_dispose( GObject *object )
 	static const gchar *thisfn = "nact_clipboard_instance_dispose";
 	NactClipboard *self;
 
-	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-	g_assert( NACT_IS_CLIPBOARD( object ));
+	g_return_if_fail( NACT_IS_CLIPBOARD( object ));
+
 	self = NACT_CLIPBOARD( object );
 
 	if( !self->private->dispose_has_run ){
 
+		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 		self->private->dispose_has_run = TRUE;
 
 		gtk_clipboard_clear( self->private->dnd );
@@ -225,14 +229,16 @@ instance_dispose( GObject *object )
 }
 
 static void
-instance_finalize( GObject *window )
+instance_finalize( GObject *instance )
 {
 	static const gchar *thisfn = "nact_clipboard_instance_finalize";
 	NactClipboard *self;
 
-	g_debug( "%s: window=%p", thisfn, ( void * ) window );
-	g_assert( NACT_IS_CLIPBOARD( window ));
-	self = NACT_CLIPBOARD( window );
+	g_return_if_fail( NACT_IS_CLIPBOARD( instance ));
+
+	g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
+
+	self = NACT_CLIPBOARD( instance );
 
 	if( self->private->primary_data ){
 		clear_primary_clipboard( self );
@@ -243,7 +249,7 @@ instance_finalize( GObject *window )
 
 	/* chain call to parent class */
 	if( G_OBJECT_CLASS( st_parent_class )->finalize ){
-		G_OBJECT_CLASS( st_parent_class )->finalize( window );
+		G_OBJECT_CLASS( st_parent_class )->finalize( instance );
 	}
 }
 
@@ -506,7 +512,9 @@ export_rows( NactClipboard *clipboard, GList *rows, const gchar *dest_folder )
 	GtkTreeIter iter;
 	NAObject *object;
 	gchar *buffer;
+	gboolean first;
 
+	first = TRUE;
 	buffer = NULL;
 	exported = NULL;
 	data = g_string_new( "" );
@@ -517,14 +525,15 @@ export_rows( NactClipboard *clipboard, GList *rows, const gchar *dest_folder )
 		if( path ){
 			gtk_tree_model_get_iter( model, &iter, path );
 			gtk_tree_path_free( path );
-			gtk_tree_model_get( model, &iter, IACTIONS_LIST_NAOBJECT_COLUMN, &object, -1 );
-			buffer = export_row_object( clipboard, object, dest_folder, &exported );
+			gtk_tree_model_get( model, &iter, TREE_COLUMN_NAOBJECT, &object, -1 );
+			buffer = export_row_object( clipboard, object, dest_folder, &exported, first );
 			if( buffer && strlen( buffer )){
 				data = g_string_append( data, buffer );
 				g_free( buffer );
 			}
 			g_object_unref( object );
 		}
+		first = FALSE;
 	}
 
 	g_list_free( exported );
@@ -539,19 +548,22 @@ export_objects( NactClipboard *clipboard, GList *objects )
 	GList *exported;
 	GList *iobj;
 	NAObject *object;
+	gboolean first;
 
+	first = TRUE;
 	buffer = NULL;
 	exported = NULL;
 	data = g_string_new( "" );
 
 	for( iobj = objects ; iobj ; iobj = iobj->next ){
 		object = NA_OBJECT( iobj->data );
-		buffer = export_row_object( clipboard, object, NULL, &exported );
+		buffer = export_row_object( clipboard, object, NULL, &exported, first );
 		if( buffer && strlen( buffer )){
 			data = g_string_append( data, buffer );
 			g_free( buffer );
 		}
 		g_object_unref( object );
+		first = FALSE;
 	}
 
 	g_list_free( exported );
@@ -563,7 +575,7 @@ export_objects( NactClipboard *clipboard, GList *objects )
  * else export to a new file in the target directory
  */
 static gchar *
-export_row_object( NactClipboard *clipboard, NAObject *object, const gchar *dest_folder, GList **exported )
+export_row_object( NactClipboard *clipboard, NAObject *object, const gchar *dest_folder, GList **exported, gboolean first )
 {
 	GList *subitems, *isub;
 	NactApplication *application;
@@ -582,11 +594,12 @@ export_row_object( NactClipboard *clipboard, NAObject *object, const gchar *dest
 		subitems = na_object_get_items( object );
 
 		for( isub = subitems ; isub ; isub = isub->next ){
-			buffer = export_row_object( clipboard, isub->data, dest_folder, exported );
+			buffer = export_row_object( clipboard, isub->data, dest_folder, exported, first );
 			if( buffer && strlen( buffer )){
 				data = g_string_append( data, buffer );
 				g_free( buffer );
 			}
+			first = FALSE;
 		}
 	}
 
@@ -603,14 +616,13 @@ export_row_object( NactClipboard *clipboard, NAObject *object, const gchar *dest
 	if( index == -1 ){
 
 		*exported = g_list_prepend( *exported, ( gpointer ) action );
-		format = nact_iprefs_get_export_format( clipboard->private->window, IPREFS_EXPORT_FORMAT );
+		format = na_iprefs_get_export_format( NA_IPREFS_EXPORT_PREFERRED_FORMAT, NULL );
 
 		if( format == IPREFS_EXPORT_FORMAT_ASK ){
-			format = nact_export_ask_user( clipboard->private->window, NA_OBJECT_ITEM( action ));
+			format = nact_export_ask_user( clipboard->private->window, NA_OBJECT_ITEM( action ), first );
 		}
 
 		if( format != IPREFS_EXPORT_NO_EXPORT ){
-
 			if( dest_folder ){
 				fname = na_exporter_to_file( NA_PIVOT( updater ), NA_OBJECT_ITEM( action), dest_folder, format, &msgs );
 				g_free( fname );
@@ -673,7 +685,7 @@ nact_clipboard_primary_set( NactClipboard *clipboard, GList *items, gint mode )
 			clear_primary_clipboard( clipboard );
 		}
 
-		na_object_count_items( items,
+		na_object_item_count_items( items,
 				( gint * ) &user_data->nb_menus,
 				( gint * ) &user_data->nb_actions,
 				( gint * ) &user_data->nb_profiles,
