@@ -40,10 +40,8 @@
 
 #include <core/na-iprefs.h>
 
-#include "base-iprefs.h"
 #include "base-window.h"
-#include "nact-gtk-utils.h"
-#include "nact-iprefs.h"
+#include "base-gtk-utils.h"
 #include "nact-application.h"
 #include "nact-main-tab.h"
 #include "nact-match-list.h"
@@ -51,15 +49,12 @@
 
 /* private interface data
  */
-struct NactIFoldersTabInterfacePrivate {
+struct _NactIFoldersTabInterfacePrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 #define ITAB_NAME						"folders"
 
-#define IPREFS_FOLDERS_DIALOG			"ifolders-chooser"
-#define IPREFS_FOLDERS_PATH				"ifolders-path"
-
 static gboolean st_initialized = FALSE;
 static gboolean st_finalized = FALSE;
 
@@ -67,7 +62,7 @@ static GType   register_type( void );
 static void    interface_base_init( NactIFoldersTabInterface *klass );
 static void    interface_base_finalize( NactIFoldersTabInterface *klass );
 
-static void    on_tab_updatable_selection_changed( NactIFoldersTab *instance, gint count_selected );
+static void    on_main_selection_changed( NactIFoldersTab *instance, GList *selected_items, gpointer user_data );
 
 static void    on_browse_folder_clicked( GtkButton *button, BaseWindow *window );
 static GSList *get_folders( void *context );
@@ -183,11 +178,8 @@ nact_ifolders_tab_runtime_init_toplevel( NactIFoldersTab *instance )
 
 		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 
-		base_window_signal_connect(
-				BASE_WINDOW( instance ),
-				G_OBJECT( instance ),
-				MAIN_WINDOW_SIGNAL_SELECTION_CHANGED,
-				G_CALLBACK( on_tab_updatable_selection_changed ));
+		base_window_signal_connect( BASE_WINDOW( instance ),
+				G_OBJECT( instance ), MAIN_SIGNAL_SELECTION_CHANGED, G_CALLBACK( on_main_selection_changed ));
 
 		nact_match_list_init_view( BASE_WINDOW( instance ), ITAB_NAME );
 
@@ -229,17 +221,22 @@ nact_ifolders_tab_dispose( NactIFoldersTab *instance )
 }
 
 static void
-on_tab_updatable_selection_changed( NactIFoldersTab *instance, gint count_selected )
+on_main_selection_changed( NactIFoldersTab *instance, GList *selected_items, gpointer user_data )
 {
+	guint count_selected;
 	NAIContext *context;
 	gboolean editable;
 	GtkWidget *button;
 
+	count_selected = g_list_length( selected_items );
 	nact_match_list_on_selection_changed( BASE_WINDOW( instance ), ITAB_NAME, count_selected );
 
-	context = nact_main_tab_get_context( NACT_MAIN_WINDOW( instance ), &editable );
+	g_object_get( G_OBJECT( instance ),
+			MAIN_PROP_CONTEXT, &context, MAIN_PROP_EDITABLE, &editable,
+			NULL );
+
 	button = base_window_get_widget( BASE_WINDOW( instance ), "FolderBrowseButton" );
-	nact_gtk_utils_set_editable( G_OBJECT( button ), editable );
+	base_gtk_utils_set_editable( G_OBJECT( button ), editable );
 }
 
 static void
@@ -270,14 +267,12 @@ on_browse_folder_clicked( GtkButton *button, BaseWindow *window )
 	gtk_widget_destroy( dialog );
 #endif
 
-	gchar *path;
+	gchar *uri, *path;
 	GtkWindow *toplevel;
 	GtkWidget *dialog;
-	NactApplication *application;
-	NAUpdater *updater;
 
-	path = NULL;
-	toplevel = base_window_get_toplevel( window );
+	uri = NULL;
+	toplevel = base_window_get_gtk_toplevel( window );
 
 	/* i18n: title of the FileChoose dialog when selecting an URI which
 	 * will be compare to Nautilus 'current_folder'
@@ -289,27 +284,26 @@ on_browse_folder_clicked( GtkButton *button, BaseWindow *window )
 			GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 			NULL );
 
-	application = NACT_APPLICATION( base_window_get_application( window ));
-	updater = nact_application_get_updater( application );
+	base_gtk_utils_restore_window_position( window, NA_IPREFS_FOLDER_CHOOSER_WSP );
 
-	base_iprefs_position_named_window( window, GTK_WINDOW( dialog ), IPREFS_FOLDERS_DIALOG );
-
-	path = na_iprefs_read_string( NA_IPREFS( updater ), IPREFS_FOLDERS_PATH, "/" );
-	if( path && g_utf8_strlen( path, -1 )){
-		gtk_file_chooser_set_current_folder( GTK_FILE_CHOOSER( dialog ), path );
+	uri = na_settings_get_string( NA_IPREFS_FOLDER_CHOOSER_URI, NULL, NULL );
+	if( uri && g_utf8_strlen( uri, -1 )){
+		gtk_file_chooser_set_current_folder_uri( GTK_FILE_CHOOSER( dialog ), uri );
 	}
-	g_free( path );
+	g_free( uri );
 
 	if( gtk_dialog_run( GTK_DIALOG( dialog )) == GTK_RESPONSE_ACCEPT ){
-		path = gtk_file_chooser_get_current_folder( GTK_FILE_CHOOSER( dialog ));
-		nact_iprefs_write_string( window, IPREFS_FOLDERS_PATH, path );
+		uri = gtk_file_chooser_get_current_folder_uri( GTK_FILE_CHOOSER( dialog ));
+		na_settings_set_string( NA_IPREFS_FOLDER_CHOOSER_URI, uri );
 
+		path = g_filename_from_uri( uri, NULL, NULL );
 		nact_match_list_insert_row( window, ITAB_NAME, path, FALSE, FALSE );
-
 		g_free( path );
+
+		g_free( uri );
 	}
 
-	base_iprefs_save_named_window_position( window, GTK_WINDOW( dialog ), IPREFS_FOLDERS_DIALOG );
+	base_gtk_utils_save_window_position( window, NA_IPREFS_FOLDER_CHOOSER_WSP );
 
 	gtk_widget_destroy( dialog );
 }
